@@ -6,7 +6,7 @@
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -17,6 +17,8 @@
 #include "H5Exception.h"
 #include "H5IdComponent.h"
 #include "H5PropList.h"
+#include "H5StrcreatProp.h"
+#include "H5LcreatProp.h"
 #include "H5LaccProp.h"
 #include "H5Location.h"
 #include "H5Object.h"
@@ -31,25 +33,31 @@ namespace H5 {
 //--------------------------------------------------------------------------
 // Function:    CompType default constructor
 ///\brief       Default constructor: Creates a stub compound datatype
-// Programmer   Binh-Minh Ribler - 2000
+// 2000
 //--------------------------------------------------------------------------
-CompType::CompType() : DataType() {}
+CompType::CompType() : DataType()
+{
+}
 
 //--------------------------------------------------------------------------
 // Function:    CompType copy constructor
 ///\brief       Copy constructor: makes copy of the original CompType object
 ///\param       original - IN: Original CompType instance
-// Programmer   Binh-Minh Ribler - 2000
+// 2000
 //--------------------------------------------------------------------------
-CompType::CompType(const CompType& original) : DataType(original) {}
+CompType::CompType(const CompType &original) : DataType(original)
+{
+}
 
 //--------------------------------------------------------------------------
 // Function:    CompType overloaded constructor
 ///\brief       Creates a CompType object using the id of an existing datatype.
 ///\param       existing_id - IN: Id of an existing compound datatype
-// Programmer   Binh-Minh Ribler - 2000
+// 2000
 //--------------------------------------------------------------------------
-CompType::CompType(const hid_t existing_id) : DataType(existing_id) {}
+CompType::CompType(const hid_t existing_id) : DataType(existing_id)
+{
+}
 
 //--------------------------------------------------------------------------
 // Function:    CompType overloaded constructor
@@ -59,9 +67,11 @@ CompType::CompType(const hid_t existing_id) : DataType(existing_id) {}
 // Description
 //              The DataType constructor calls the C API H5Tcreate to create
 //              the compound datatype.
-// Programmer   Binh-Minh Ribler - 2000
+// 2000
 //--------------------------------------------------------------------------
-CompType::CompType(size_t size) : DataType(H5T_COMPOUND, size) {}
+CompType::CompType(size_t size) : DataType(H5T_COMPOUND, size)
+{
+}
 
 //--------------------------------------------------------------------------
 // Function:    CompType overloaded constructor
@@ -69,16 +79,15 @@ CompType::CompType(size_t size) : DataType(H5T_COMPOUND, size) {}
 ///\param       dataset - IN: Dataset that this enum datatype associates with
 ///\return      CompType instance
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - 2000
+// 2000
 //--------------------------------------------------------------------------
-CompType::CompType(const DataSet& dataset) : DataType()
+CompType::CompType(const DataSet &dataset) : DataType()
 {
     // Calls C function H5Dget_type to get the id of the datatype
     id = H5Dget_type(dataset.getId());
 
     // If the datatype id is invalid, throw exception
-    if(id < 0)
-    {
+    if (id < 0) {
         throw DataSetIException("CompType constructor", "H5Dget_type failed");
     }
 }
@@ -90,14 +99,14 @@ CompType::CompType(const DataSet& dataset) : DataType()
 ///\param       loc       - IN: Location of the type
 ///\param       type_name - IN: Compound type name
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - Sept 2017
+// Sept 2017
 // Description
 //              In 1.8.20, this constructor was introduced and may replace the
 //              existing function CommonFG::openCompType(const char*) to
 //              improve usability.
 //              -BMR, Sept 2017
 //--------------------------------------------------------------------------
-CompType::CompType(const H5Location& loc, const char *type_name) : DataType()
+CompType::CompType(const H5Location &loc, const char *type_name) : DataType()
 {
     id = p_opentype(loc, type_name);
 }
@@ -109,14 +118,14 @@ CompType::CompType(const H5Location& loc, const char *type_name) : DataType()
 ///\param       loc       - IN: Location of the type
 ///\param       type_name - IN: Compound type name
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - Sept 2017
+// Sept 2017
 // Description
 //              In 1.8.20, this constructor was introduced and may replace the
 //              existing function CommonFG::openCompType(const H5std_string&) to
 //              improve usability.
 //              -BMR, Sept 2017
 //--------------------------------------------------------------------------
-CompType::CompType(const H5Location& loc, const H5std_string& type_name) : DataType()
+CompType::CompType(const H5Location &loc, const H5std_string &type_name) : DataType()
 {
     id = p_opentype(loc, type_name.c_str());
 }
@@ -126,9 +135,10 @@ CompType::CompType(const H5Location& loc, const H5std_string& type_name) : DataT
 ///\brief       Returns a CompType object via DataType* by decoding the
 ///             binary object description of this datatype.
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - Sept 2017
+// Sept 2017
 //--------------------------------------------------------------------------
-DataType* CompType::decode() const
+DataType *
+CompType::decode() const
 {
     hid_t encoded_cmptype_id = H5I_INVALID_HID;
     try {
@@ -139,7 +149,7 @@ DataType* CompType::decode() const
     }
     CompType *encoded_cmptype = new CompType;
     encoded_cmptype->p_setId(encoded_cmptype_id);
-    return(encoded_cmptype);
+    return (encoded_cmptype);
 }
 
 //--------------------------------------------------------------------------
@@ -147,17 +157,17 @@ DataType* CompType::decode() const
 ///\brief       Returns the number of members in this compound datatype.
 ///\return      Number of members
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - 2000
+// 2000
 //--------------------------------------------------------------------------
-int CompType::getNmembers() const
+int
+CompType::getNmembers() const
 {
     int num_members = H5Tget_nmembers(id);
-    if(num_members < 0)
-    {
+    if (num_members < 0) {
         throw DataTypeIException("CompType::getNmembers",
-                "H5Tget_nmembers returns negative number of members");
+                                 "H5Tget_nmembers returns negative number of members");
     }
-    return(num_members);
+    return (num_members);
 }
 
 //--------------------------------------------------------------------------
@@ -166,46 +176,62 @@ int CompType::getNmembers() const
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      Name of member
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - 2000
+// 2000
 //--------------------------------------------------------------------------
-H5std_string CompType::getMemberName(unsigned member_num) const
+H5std_string
+CompType::getMemberName(unsigned member_num) const
 {
-    char* member_name_C = H5Tget_member_name(id, member_num);
-    if(member_name_C == NULL)  // NULL means failure
+    char *member_name_C = H5Tget_member_name(id, member_num);
+    if (member_name_C == NULL) // NULL means failure
     {
         throw DataTypeIException("CompType::getMemberName",
-                "H5Tget_member_name returns NULL for member name");
+                                 "H5Tget_member_name returns NULL for member name");
     }
     H5std_string member_name = H5std_string(member_name_C); // convert C string to string
-    H5free_memory(member_name_C); // free the C string
-    return(member_name); // return the member name string
+    H5free_memory(member_name_C);                           // free the C string
+    return (member_name);                                   // return the member name string
 }
 
 //--------------------------------------------------------------------------
 // Function:    CompType::getMemberIndex
 ///\brief       Returns the index of a member in this compound datatype.
-///\param       name - IN: Name of the member
+///\param       name - IN: Name of the member - \c char*
 ///\return      Index of member
 ///\exception   H5::DataTypeIException
 ///\par Description
 ///             Members are stored in no particular order with numbers 0
 ///             through N-1, where N is the value returned by the member
 ///             function \c CompType::getNmembers.
-// Programmer   Binh-Minh Ribler - May 16, 2002
+// May 2002
 //--------------------------------------------------------------------------
-int CompType::getMemberIndex(const char* name) const
+int
+CompType::getMemberIndex(const char *name) const
 {
     int member_index = H5Tget_member_index(id, name);
-    if(member_index < 0)
-    {
-        throw DataTypeIException("CompType::getMemberIndex",
-                "H5Tget_member_index returns negative value");
+    if (member_index < 0) {
+        throw DataTypeIException("CompType::getMemberIndex", "H5Tget_member_index returns negative value");
     }
-    return(member_index);
+    return (member_index);
 }
-int CompType::getMemberIndex(const H5std_string& name) const
+
+//--------------------------------------------------------------------------
+// Function:    CompType::getMemberIndex
+///\brief       This is an overloaded member function, provided for convenience.
+///             It differs from the above function in that it takes an
+///             \c H5std_string for \a name.
+///\param       name - IN: Name of the member - \c H5std_string
+///\return      Index of member
+///\exception   H5::DataTypeIException
+///\par Description
+///             Members are stored in no particular order with numbers 0
+///             through N-1, where N is the value returned by the member
+///             function \c CompType::getNmembers.
+// Apr 2018
+//--------------------------------------------------------------------------
+int
+CompType::getMemberIndex(const H5std_string &name) const
 {
-    return(getMemberIndex(name.c_str()));
+    return (getMemberIndex(name.c_str()));
 }
 
 //--------------------------------------------------------------------------
@@ -214,19 +240,20 @@ int CompType::getMemberIndex(const H5std_string& name) const
 ///             respect to the beginning of the compound data type datum.
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      Byte offset
-// Programmer   Binh-Minh Ribler - 2000
+// 2000
 // Description
 ///             Members are stored in no particular order with numbers 0
 ///             through N-1, where N is the value returned by the member
 ///             function \c CompType::getNmembers.
 //
 //              Note that byte offset being returned as 0 doesn't indicate
-//              a failure. (According to Quincey)
+//              a failure.
 //--------------------------------------------------------------------------
-size_t CompType::getMemberOffset(unsigned member_num) const
+size_t
+CompType::getMemberOffset(unsigned member_num) const
 {
     size_t offset = H5Tget_member_offset(id, member_num);
-    return(offset);
+    return (offset);
 }
 
 //--------------------------------------------------------------------------
@@ -235,33 +262,32 @@ size_t CompType::getMemberOffset(unsigned member_num) const
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      Type class of the member
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - 2000
+// 2000
 // Modification
 //              Modified to use H5Tget_member_class instead. - Jul, 2005
 //--------------------------------------------------------------------------
-H5T_class_t CompType::getMemberClass(unsigned member_num) const
+H5T_class_t
+CompType::getMemberClass(unsigned member_num) const
 {
     H5T_class_t member_class = H5Tget_member_class(id, member_num);
-    if(member_class == H5T_NO_CLASS)
-    {
-        throw DataTypeIException("CompType::getMemberClass",
-                "H5Tget_member_class returns H5T_NO_CLASS");
+    if (member_class == H5T_NO_CLASS) {
+        throw DataTypeIException("CompType::getMemberClass", "H5Tget_member_class returns H5T_NO_CLASS");
     }
-    return(member_class);
+    return (member_class);
 }
 
 // This private member function calls the C API to get the identifier
 // of the specified member.  It provides the id to construct appropriate
 // sub-types in the functions getMemberXxxType below, where Xxx indicates
 // the sub-types.
-hid_t CompType::p_get_member_type(unsigned member_num) const
+hid_t
+CompType::p_get_member_type(unsigned member_num) const
 {
     // get the id of the specified member first
     hid_t member_type_id = H5Tget_member_type(id, member_num);
-    if(member_type_id > 0)
-        return(member_type_id);
-    else
-    {
+    if (member_type_id > 0)
+        return (member_type_id);
+    else {
         // p_get_member_type is private, caller will catch this exception
         // then throw another with appropriate API name
         throw DataTypeIException("", "H5Tget_member_type failed");
@@ -275,16 +301,17 @@ hid_t CompType::p_get_member_type(unsigned member_num) const
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      DataType instance
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - 2000
+// 2000
 //--------------------------------------------------------------------------
-DataType CompType::getMemberDataType(unsigned member_num) const
+DataType
+CompType::getMemberDataType(unsigned member_num) const
 {
     try {
         DataType datatype;
         f_DataType_setId(&datatype, p_get_member_type(member_num));
-        return(datatype);
+        return (datatype);
     }
-    catch (DataTypeIException& E) {
+    catch (DataTypeIException &E) {
         throw DataTypeIException("CompType::getMemberDataType", E.getDetailMsg());
     }
 }
@@ -296,16 +323,17 @@ DataType CompType::getMemberDataType(unsigned member_num) const
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      ArrayType instance
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - Jul, 2005
+// Jul 2005
 //--------------------------------------------------------------------------
-ArrayType CompType::getMemberArrayType(unsigned member_num) const
+ArrayType
+CompType::getMemberArrayType(unsigned member_num) const
 {
     try {
-        ArrayType arraytype(p_get_member_type(member_num));
+        ArrayType arraytype;
         f_DataType_setId(&arraytype, p_get_member_type(member_num));
-        return(arraytype);
+        return (arraytype);
     }
-    catch (DataTypeIException& E) {
+    catch (DataTypeIException &E) {
         throw DataTypeIException("CompType::getMemberArrayType", E.getDetailMsg());
     }
 }
@@ -317,16 +345,17 @@ ArrayType CompType::getMemberArrayType(unsigned member_num) const
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      CompType instance
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - 2000
+// 2000
 //--------------------------------------------------------------------------
-CompType CompType::getMemberCompType(unsigned member_num) const
+CompType
+CompType::getMemberCompType(unsigned member_num) const
 {
     try {
-      CompType comptype(p_get_member_type(member_num));
+        CompType comptype;
         f_DataType_setId(&comptype, p_get_member_type(member_num));
-        return(comptype);
+        return (comptype);
     }
-    catch (DataTypeIException& E) {
+    catch (DataTypeIException &E) {
         throw DataTypeIException("CompType::getMemberCompType", E.getDetailMsg());
     }
 }
@@ -338,16 +367,17 @@ CompType CompType::getMemberCompType(unsigned member_num) const
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      EnumType instance
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - 2000
+// 2000
 //--------------------------------------------------------------------------
-EnumType CompType::getMemberEnumType(unsigned member_num) const
+EnumType
+CompType::getMemberEnumType(unsigned member_num) const
 {
     try {
-      EnumType enumtype(p_get_member_type(member_num));
+        EnumType enumtype;
         f_DataType_setId(&enumtype, p_get_member_type(member_num));
-        return(enumtype);
+        return (enumtype);
     }
-    catch (DataTypeIException& E) {
+    catch (DataTypeIException &E) {
         throw DataTypeIException("CompType::getMemberEnumType", E.getDetailMsg());
     }
 }
@@ -359,16 +389,17 @@ EnumType CompType::getMemberEnumType(unsigned member_num) const
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      IntType instance
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - 2000
+// 2000
 //--------------------------------------------------------------------------
-IntType CompType::getMemberIntType(unsigned member_num) const
+IntType
+CompType::getMemberIntType(unsigned member_num) const
 {
     try {
-      IntType inttype(p_get_member_type(member_num));
+        IntType inttype;
         f_DataType_setId(&inttype, p_get_member_type(member_num));
-        return(inttype);
+        return (inttype);
     }
-    catch (DataTypeIException& E) {
+    catch (DataTypeIException &E) {
         throw DataTypeIException("CompType::getMemberIntType", E.getDetailMsg());
     }
 }
@@ -380,16 +411,17 @@ IntType CompType::getMemberIntType(unsigned member_num) const
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      FloatType instance
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - 2000
+// 2000
 //--------------------------------------------------------------------------
-FloatType CompType::getMemberFloatType(unsigned member_num) const
+FloatType
+CompType::getMemberFloatType(unsigned member_num) const
 {
     try {
-      FloatType floatype(p_get_member_type(member_num));
+        FloatType floatype;
         f_DataType_setId(&floatype, p_get_member_type(member_num));
-        return(floatype);
+        return (floatype);
     }
-    catch (DataTypeIException& E) {
+    catch (DataTypeIException &E) {
         throw DataTypeIException("CompType::getMemberFloatType", E.getDetailMsg());
     }
 }
@@ -401,16 +433,17 @@ FloatType CompType::getMemberFloatType(unsigned member_num) const
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      StrType instance
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - 2000
+// 2000
 //--------------------------------------------------------------------------
-StrType CompType::getMemberStrType(unsigned member_num) const
+StrType
+CompType::getMemberStrType(unsigned member_num) const
 {
     try {
-      StrType strtype(p_get_member_type(member_num));
+        StrType strtype;
         f_DataType_setId(&strtype, p_get_member_type(member_num));
-        return(strtype);
+        return (strtype);
     }
-    catch (DataTypeIException& E) {
+    catch (DataTypeIException &E) {
         throw DataTypeIException("CompType::getMemberStrType", E.getDetailMsg());
     }
 }
@@ -422,16 +455,17 @@ StrType CompType::getMemberStrType(unsigned member_num) const
 ///\param       member_num - IN: Zero-based index of the member
 ///\return      VarLenType instance
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - Jul, 2005
+// Jul 2005
 //--------------------------------------------------------------------------
-VarLenType CompType::getMemberVarLenType(unsigned member_num) const
+VarLenType
+CompType::getMemberVarLenType(unsigned member_num) const
 {
     try {
-      VarLenType varlentype(p_get_member_type(member_num));
+        VarLenType varlentype;
         f_DataType_setId(&varlentype, p_get_member_type(member_num));
-        return(varlentype);
+        return (varlentype);
     }
-    catch (DataTypeIException& E) {
+    catch (DataTypeIException &E) {
         throw DataTypeIException("CompType::getMemberVarLenType", E.getDetailMsg());
     }
 }
@@ -476,20 +510,20 @@ void CompType::getMemberType(unsigned member_num, StrType& strtype) const
 ///\param       offset - IN: Offset in memory structure of the field to insert
 ///\param       new_member - IN: New member to be inserted
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - 2000
+// 2000
 //--------------------------------------------------------------------------
-void CompType::insertMember(const H5std_string& name, size_t offset, const DataType& new_member) const
+void
+CompType::insertMember(const H5std_string &name, size_t offset, const DataType &new_member) const
 {
     // Convert string to C-string
-    const char* name_C;
-    name_C = name.c_str();  // name_C refers to the contents of name as a C-str
+    const char *name_C;
+    name_C = name.c_str(); // name_C refers to the contents of name as a C-str
 
-    hid_t new_member_id = new_member.getId();  // get new_member id for C API
+    hid_t new_member_id = new_member.getId(); // get new_member id for C API
 
     // Call C routine H5Tinsert to add the new member
     herr_t ret_value = H5Tinsert(id, name_C, offset, new_member_id);
-    if(ret_value < 0)
-    {
+    if (ret_value < 0) {
         throw DataTypeIException("CompType::insertMember", "H5Tinsert failed");
     }
 }
@@ -499,14 +533,14 @@ void CompType::insertMember(const H5std_string& name, size_t offset, const DataT
 ///\brief       Recursively removes padding from within a compound datatype.
 ///
 ///\exception   H5::DataTypeIException
-// Programmer   Binh-Minh Ribler - 2000
+// 2000
 //--------------------------------------------------------------------------
-void CompType::pack() const
+void
+CompType::pack() const
 {
     // Calls C routine H5Tpack to remove padding
     herr_t ret_value = H5Tpack(id);
-    if(ret_value < 0)
-    {
+    if (ret_value < 0) {
         throw DataTypeIException("CompType::pack", "H5Tpack failed");
     }
 }
@@ -518,14 +552,14 @@ void CompType::pack() const
 ///\exception   H5::DataTypeIException
 // Note
 //      H5Tset_size works on atom datatypes and compound datatypes only
-// Programmer   Binh-Minh Ribler - 2014
+// March 2014
 //--------------------------------------------------------------------------
-void CompType::setSize(size_t size) const
+void
+CompType::setSize(size_t size) const
 {
     // Call C routine H5Tset_size to set the total size
     herr_t ret_value = H5Tset_size(id, size);
-    if (ret_value < 0)
-    {
+    if (ret_value < 0) {
         throw DataTypeIException("CompType::setSize", "H5Tset_size failed");
     }
 }
@@ -533,8 +567,10 @@ void CompType::setSize(size_t size) const
 //--------------------------------------------------------------------------
 // Function:    CompType destructor
 ///\brief       Properly terminates access to this compound datatype.
-// Programmer   Binh-Minh Ribler - 2000
+// 2000
 //--------------------------------------------------------------------------
-CompType::~CompType() {}
+CompType::~CompType()
+{
+}
 
-} // end namespace
+} // namespace H5
