@@ -11,18 +11,16 @@
 !
 ! COPYRIGHT
 !  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
-!  Copyright by The HDF Group.                                               *
-!  Copyright by the Board of Trustees of the University of Illinois.         *
-!  All rights reserved.                                                      *
-!  *
-!  This file is part of HDF5.  The full HDF5 copyright notice, including     *
-!  terms governing use, modification, and redistribution, is contained in    *
-!  the files COPYING and Copyright.html.  COPYING can be found at the root   *
-!  of the source code distribution tree; Copyright.html can be found at the  *
-!  root level of an installed copy of the electronic HDF5 document set and   *
-!  is linked from the top-level documents page.  It can also be found at     *
-!  http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
-!  access to either file, you may request a copy from help@hdfgroup.org.     *
+!  Copyright by The HDF Group.                                                 *
+!  Copyright by the Board of Trustees of the University of Illinois.           *
+!  All rights reserved.                                                        *
+!                                                                              *
+!  This file is part of HDF5.  The full HDF5 copyright notice, including       *
+!  terms governing use, modification, and redistribution, is contained in      *
+!  the COPYING file, which can be found at the root of the source code         *
+!  distribution tree, or in https://www.hdfgroup.org/licenses.                 *
+!  If you do not have access to either file, you may request a copy from       *
+!  help@hdfgroup.org.                                                          *
 !  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 !
 ! NOTES
@@ -89,12 +87,10 @@ MODULE H5P_PROVISIONAL
   END INTERFACE
 
   INTERFACE
-     INTEGER FUNCTION h5pget_fill_value_c(prp_id, type_id, fillvalue)
+     INTEGER FUNCTION h5pget_fill_value_c(prp_id, type_id, fillvalue) &
+          BIND(C, NAME='h5pget_fill_value_c')
        USE H5GLOBAL
-       USE, INTRINSIC :: ISO_C_BINDING
-       !DEC$IF DEFINED(HDF5F90_WINDOWS)
-       !DEC$ATTRIBUTES C,reference,decorate,alias:'H5PGET_FILL_VALUE_C'::h5pget_fill_value_c
-       !DEC$ENDIF
+       USE, INTRINSIC :: ISO_C_BINDING, ONLY : c_ptr
        INTEGER(HID_T), INTENT(IN) :: prp_id  ! Property list identifier
        INTEGER(HID_T), INTENT(IN) :: type_id ! Datatype identifier of
                                              ! of fillvalue datatype
@@ -104,12 +100,10 @@ MODULE H5P_PROVISIONAL
   END INTERFACE
 
   INTERFACE
-     INTEGER FUNCTION h5pset_fill_value_c(prp_id, type_id, fillvalue)
+     INTEGER FUNCTION h5pset_fill_value_c(prp_id, type_id, fillvalue) &
+          BIND(C, NAME='h5pset_fill_value_c')
        USE H5GLOBAL
-       USE, INTRINSIC :: ISO_C_BINDING
-       !DEC$IF DEFINED(HDF5F90_WINDOWS)
-       !DEC$ATTRIBUTES C,reference,decorate,alias:'H5PSET_FILL_VALUE_C'::h5pset_fill_value_c
-       !DEC$ENDIF
+       USE, INTRINSIC :: ISO_C_BINDING, ONLY : c_ptr
        INTEGER(HID_T), INTENT(IN) :: prp_id  ! Property list identifier
        INTEGER(HID_T), INTENT(IN) :: type_id ! Datatype identifier of
                                              ! of fillvalue datatype
@@ -119,43 +113,36 @@ MODULE H5P_PROVISIONAL
   END INTERFACE
 
   INTERFACE
-     INTEGER FUNCTION h5pset_c(prp_id, name, name_len, value)
+     INTEGER FUNCTION h5pset_c(prp_id, name, name_len, value) &
+          BIND(C, NAME='h5pset_c')
+       USE, INTRINSIC :: ISO_C_BINDING, ONLY : c_char, c_ptr
        USE H5GLOBAL
-       USE, INTRINSIC :: ISO_C_BINDING
-       !DEC$IF DEFINED(HDF5F90_WINDOWS)
-       !DEC$ATTRIBUTES C,reference,decorate,alias:'H5PSET_C'::h5pset_c
-       !DEC$ENDIF
        INTEGER(HID_T), INTENT(IN) :: prp_id  ! Property list identifier
-       CHARACTER(LEN=*), INTENT(IN) :: name  ! Name of property to modify
+       CHARACTER(KIND=C_CHAR), DIMENSION(*), INTENT(IN) :: name  ! Name of property to modify
        INTEGER :: name_len
        TYPE(C_PTR), VALUE :: value ! Property value
      END FUNCTION h5pset_c
   END INTERFACE
 
   INTERFACE
-     INTEGER FUNCTION h5pget_c(prp_id, name, name_len, value)
-       USE, INTRINSIC :: ISO_C_BINDING
+     INTEGER FUNCTION h5pget_c(prp_id, name, name_len, value) &
+          BIND(C, NAME='h5pget_c')
+       USE, INTRINSIC :: ISO_C_BINDING, ONLY : c_char, c_ptr
        USE H5GLOBAL
-       !DEC$IF DEFINED(HDF5F90_WINDOWS)
-       !DEC$ATTRIBUTES C,reference,decorate,alias:'H5PGET_C'::h5pget_c
-       !DEC$ENDIF
        INTEGER(HID_T), INTENT(IN) :: prp_id  ! Property list identifier
-       CHARACTER(LEN=*), INTENT(IN) :: name  ! Name of property to modify
+       CHARACTER(KIND=C_CHAR), DIMENSION(*), INTENT(IN) :: name  ! Name of property to modify
        INTEGER :: name_len
        TYPE(C_PTR), VALUE :: value ! Property value
      END FUNCTION h5pget_c
   END INTERFACE
 
   INTERFACE
-     INTEGER FUNCTION h5pregister_c(class, name, name_len, size, value)
-       USE iso_c_binding
+     INTEGER FUNCTION h5pregister_c(class, name, name_len, size, value) &
+          BIND(C, NAME='h5pregister_c')
+       USE, INTRINSIC :: ISO_C_BINDING, ONLY : c_char, c_ptr
        USE H5GLOBAL
-       !DEC$IF DEFINED(HDF5F90_WINDOWS)
-       !DEC$ATTRIBUTES C,reference,decorate,alias:'H5PREGISTER_C'::h5pregister_c
-       !DEC$ENDIF
-       !DEC$ATTRIBUTES reference :: name
        INTEGER(HID_T), INTENT(IN) :: class
-       CHARACTER(LEN=*), INTENT(IN) :: name
+       CHARACTER(KIND=C_CHAR), DIMENSION(*), INTENT(IN) :: name
        INTEGER, INTENT(IN)         :: name_len
        INTEGER(SIZE_T), INTENT(IN) :: size
        TYPE(C_PTR), INTENT(IN), VALUE :: value
@@ -163,18 +150,15 @@ MODULE H5P_PROVISIONAL
   END INTERFACE
 
   INTERFACE
-     INTEGER FUNCTION h5pinsert_c(plist, name, name_len, size, value)
-       USE iso_c_binding
+     INTEGER FUNCTION h5pinsert_c(plist, name, name_len, size, value) &
+          BIND(C, NAME='h5pinsert_c')
+       USE, INTRINSIC :: ISO_C_BINDING, ONLY : c_char, c_ptr
        USE H5GLOBAL
-       !DEC$IF DEFINED(HDF5F90_WINDOWS)
-       !DEC$ATTRIBUTES C,reference,decorate,alias:'H5PINSERT_C'::h5pinsert_c
-       !DEC$ENDIF
-       !DEC$ATTRIBUTES reference :: name
        INTEGER(HID_T), INTENT(IN) :: plist
-       CHARACTER(LEN=*), INTENT(IN) :: name
+       CHARACTER(KIND=C_CHAR), DIMENSION(*), INTENT(IN) :: name
        INTEGER, INTENT(IN)         :: name_len
        INTEGER(SIZE_T), INTENT(IN) :: size
-       TYPE(c_ptr), INTENT(IN), value :: value
+       TYPE(C_PTR), INTENT(IN), VALUE :: value
      END FUNCTION h5pinsert_c
   END INTERFACE
 
@@ -485,7 +469,7 @@ CONTAINS
 !!  SUBROUTINE h5pget_fill_value_f(prp_id, type_id, fillvalue, hdferr)
 !!    INTEGER(HID_T), INTENT(IN)  :: prp_id 
 !!    INTEGER(HID_T), INTENT(IN)  :: type_id
-!!    TYPE(C_PTR)   , INTENT(OUT) :: fillvalue
+!!    TYPE(C_PTR)                 :: fillvalue
 !!    INTEGER       , INTENT(OUT) :: hdferr
 !*****
 
@@ -496,7 +480,7 @@ CONTAINS
     INTEGER(HID_T), INTENT(IN) :: type_id ! Datatype identifier of
                                           ! of fillvalue datatype
                                           ! (in memory)
-    TYPE(C_PTR), INTENT(OUT) :: fillvalue ! Fillvalue
+    TYPE(C_PTR) :: fillvalue              ! Fillvalue
     INTEGER, INTENT(OUT) :: hdferr        ! Error code
 
     hdferr = h5pget_fill_value_c(prp_id, type_id, fillvalue)
@@ -1140,18 +1124,12 @@ CONTAINS
     TYPE(C_FUNPTR) :: create_default, copy_default, close_default
     INTERFACE
        INTEGER FUNCTION h5pcreate_class_c(parent, name, name_len, class, &
-            create, create_data, &
-            copy, copy_data, &
-            close, close_data)
-
-         USE iso_c_binding
+            create, create_data, copy, copy_data, close, close_data) &
+          BIND(C, NAME='h5pcreate_class_c')
+         USE, INTRINSIC :: ISO_C_BINDING, ONLY : c_char, c_ptr, c_funptr
          USE H5GLOBAL
-         !DEC$IF DEFINED(HDCLOSEF90_WINDOWS)
-         !DEC$ATTRIBUTES C,reference,decorate,alias:'H5PCREATE_CLASS_C'::h5pcreate_class_c
-         !DEC$ENDIF
-         !DEC$ATTRIBUTES reference :: name
          INTEGER(HID_T), INTENT(IN) :: parent
-         CHARACTER(LEN=*), INTENT(IN) :: name
+         CHARACTER(KIND=C_CHAR), DIMENSION(*), INTENT(IN) :: name
          INTEGER, INTENT(IN)         :: name_len
          INTEGER(HID_T), INTENT(OUT) :: class
          TYPE(C_PTR), VALUE :: create_data, copy_data, close_data
@@ -1213,12 +1191,10 @@ CONTAINS
     INTEGER        , INTENT(OUT) :: hdferr
 !*****
     INTERFACE
-       INTEGER FUNCTION h5pset_file_image_c(fapl_id, buf_ptr, buf_len)
-         USE iso_c_binding
+       INTEGER FUNCTION h5pset_file_image_c(fapl_id, buf_ptr, buf_len) &
+            BIND(C, NAME='h5pset_file_image_c')
+         USE, INTRINSIC :: ISO_C_BINDING, ONLY : c_ptr
          USE H5GLOBAL
-         !DEC$IF DEFINED(HDCLOSEF90_WINDOWS)
-         !DEC$ATTRIBUTES C,reference,decorate,alias:'H5PSET_FILE_IMAGE_C'::h5pset_file_image_c
-         !DEC$ENDIF
          INTEGER(HID_T), INTENT(IN) :: fapl_id
          TYPE(C_PTR), VALUE :: buf_ptr
          INTEGER(SIZE_T), INTENT(IN)  :: buf_len
@@ -1271,12 +1247,10 @@ CONTAINS
     
 !*****
     INTERFACE
-       INTEGER FUNCTION h5pget_file_image_c(fapl_id, buf_ptr, buf_len_ptr)
-         USE iso_c_binding
+       INTEGER FUNCTION h5pget_file_image_c(fapl_id, buf_ptr, buf_len_ptr) &
+            BIND(C, NAME='h5pget_file_image_c')
+         USE, INTRINSIC :: ISO_C_BINDING, ONLY : c_ptr
          USE H5GLOBAL
-         !DEC$IF DEFINED(HDCLOSEF90_WINDOWS)
-         !DEC$ATTRIBUTES C,reference,decorate,alias:'H5PGET_FILE_IMAGE_C'::h5pget_file_image_c
-         !DEC$ENDIF
          INTEGER(HID_T), INTENT(IN) :: fapl_id
          TYPE(C_PTR), DIMENSION(*), INTENT(OUT)  :: buf_ptr
          INTEGER(SIZE_T), INTENT(OUT)  :: buf_len_ptr
