@@ -14,24 +14,22 @@
 !
 ! COPYRIGHT
 !  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
-!  Copyright by The HDF Group.                                               *
-!  Copyright by the Board of Trustees of the University of Illinois.         *
-!  All rights reserved.                                                      *
-!  *
-!  This file is part of HDF5.  The full HDF5 copyright notice, including     *
-!  terms governing use, modification, and redistribution, is contained in    *
-!  the files COPYING and Copyright.html.  COPYING can be found at the root   *
-!  of the source code distribution tree; Copyright.html can be found at the  *
-!  root level of an installed copy of the electronic HDF5 document set and   *
-!  is linked from the top-level documents page.  It can also be found at     *
-!  http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
-!  access to either file, you may request a copy from help@hdfgroup.org.     *
+!  Copyright by The HDF Group.                                                 *
+!  Copyright by the Board of Trustees of the University of Illinois.           *
+!  All rights reserved.                                                        *
+!                                                                              *
+!  This file is part of HDF5.  The full HDF5 copyright notice, including       *
+!  terms governing use, modification, and redistribution, is contained in      *
+!  the COPYING file, which can be found at the root of the source code         *
+!  distribution tree, or in https://www.hdfgroup.org/licenses.                 *
+!  If you do not have access to either file, you may request a copy from       *
+!  help@hdfgroup.org.                                                          *
 !  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 !
 ! NOTES
 !                         *** IMPORTANT ***
 !  If you add a new H5R function you must add the function name to the
-!  Windows dll file 'hdf5_fortrandll.def' in the fortran/src directory.
+!  Windows dll file 'hdf5_fortrandll.def.in' in the fortran/src directory.
 !  This is needed for Windows based operating systems.
 !
 !*****
@@ -90,29 +88,24 @@ MODULE H5R_PROVISIONAL
   END INTERFACE
 
   INTERFACE
-     INTEGER FUNCTION h5rget_name_ptr_c(loc_id, ref_type, ref, name, name_len, size_default)
-       USE, INTRINSIC :: ISO_C_BINDING
+     INTEGER FUNCTION h5rget_name_ptr_c(loc_id, ref_type, ref, name, name_len, size_default) &
+          BIND(C, NAME='h5rget_name_ptr_c')
+       USE, INTRINSIC :: ISO_C_BINDING, ONLY : c_char, c_ptr
        USE H5GLOBAL
-       !DEC$IF DEFINED(HDF5F90_WINDOWS)
-       !DEC$ATTRIBUTES C,reference,decorate,alias:'H5RGET_NAME_PTR_C':: h5rget_name_ptr_c
-       !DEC$ENDIF
-       !DEC$ATTRIBUTES reference :: name
        INTEGER(HID_T), INTENT(IN) :: loc_id
        INTEGER, INTENT(IN) :: ref_type
        TYPE(C_PTR), INTENT(IN), VALUE :: ref
-       CHARACTER(LEN=*), INTENT(OUT) :: name
+       CHARACTER(KIND=C_CHAR), DIMENSION(*), INTENT(IN) :: name
        INTEGER(SIZE_T) :: name_len
        INTEGER(SIZE_T) :: size_default
      END FUNCTION h5rget_name_ptr_c
   END INTERFACE
 
   INTERFACE
-     INTEGER FUNCTION h5rdereference_ptr_c(obj_id, ref_type, ref, ref_obj_id)
+     INTEGER FUNCTION h5rdereference_ptr_c(obj_id, ref_type, ref, ref_obj_id) &
+          BIND(C, NAME='h5rdereference_ptr_c')
+       USE, INTRINSIC :: ISO_C_BINDING, ONLY : c_ptr
        USE H5GLOBAL
-       USE, INTRINSIC :: ISO_C_BINDING
-       !DEC$IF DEFINED(HDF5F90_WINDOWS)
-       !DEC$ATTRIBUTES C,reference,decorate,alias:'H5RDEREFERENCE_PTR_C':: h5rdereference_ptr_c
-       !DEC$ENDIF
        INTEGER(HID_T), INTENT(IN) :: obj_id
        INTEGER, INTENT(IN) :: ref_type
        TYPE(C_PTR), INTENT(IN), VALUE :: ref
@@ -121,16 +114,13 @@ MODULE H5R_PROVISIONAL
   END INTERFACE
 
   INTERFACE
-     INTEGER FUNCTION h5rcreate_ptr_c(ref, loc_id, name, namelen, ref_type, space_id)
-       USE, INTRINSIC :: ISO_C_BINDING
+     INTEGER FUNCTION h5rcreate_ptr_c(ref, loc_id, name, namelen, ref_type, space_id) &
+          BIND(C, NAME='h5rcreate_ptr_c')
+       USE, INTRINSIC :: ISO_C_BINDING, ONLY : c_char, c_ptr
        USE H5GLOBAL
-       !DEC$IF DEFINED(HDF5F90_WINDOWS)
-       !DEC$ATTRIBUTES C,reference,decorate,alias:'H5RCREATE_PTR_C':: h5rcreate_ptr_c
-       !DEC$ENDIF
-       !DEC$ATTRIBUTES reference :: name
        TYPE(C_PTR), VALUE :: ref
        INTEGER(HID_T), INTENT(IN) :: loc_id
-       CHARACTER(LEN=*), INTENT(IN) :: name
+       CHARACTER(KIND=C_CHAR), DIMENSION(*), INTENT(IN) :: name
        INTEGER :: namelen
        INTEGER, INTENT(IN) :: ref_type
        INTEGER(HID_T), INTENT(IN) :: space_id
@@ -138,12 +128,10 @@ MODULE H5R_PROVISIONAL
   END INTERFACE
 
   INTERFACE
-     INTEGER FUNCTION h5rget_region_ptr_c(dset_id, ref, space_id)
-       USE, INTRINSIC :: ISO_C_BINDING
+     INTEGER FUNCTION h5rget_region_ptr_c(dset_id, ref, space_id) &
+          BIND(C, NAME='h5rget_region_ptr_c')
+       USE, INTRINSIC :: ISO_C_BINDING, ONLY : c_ptr
        USE H5GLOBAL
-       !DEC$IF DEFINED(HDF5F90_WINDOWS)
-       !DEC$ATTRIBUTES C,reference,decorate,alias:'H5RGET_REGION_PTR_C':: h5rget_region_ptr_c
-       !DEC$ENDIF
        INTEGER(HID_T), INTENT(IN) :: dset_id
        TYPE(C_PTR), VALUE :: ref
        INTEGER(HID_T), INTENT(OUT) :: space_id
@@ -238,7 +226,6 @@ CONTAINS
     INTEGER(HID_T), INTENT(OUT) :: space_id    ! Space identifier
     INTEGER, INTENT(OUT) :: hdferr             ! Error code
 !*****
-    INTEGER :: ref_f(REF_REG_BUF_LEN)          ! Local buffer to pass reference
 
     hdferr = h5rget_region_ptr_c(dset_id, ref, space_id )
 
@@ -258,9 +245,7 @@ CONTAINS
 !  name      - name of the object at the specified location
 ! Outputs:
 !  ref 	     - reference to the specified object
-!  hdferr:   - error code
-!               Success:  0
-!               Failure: -1
+!  hdferr    - returns 0 if successful and -1 if fails
 ! AUTHOR
 !  Elena Pourmal
 !  August 12, 1999
@@ -284,7 +269,6 @@ CONTAINS
     INTEGER, INTENT(OUT) :: hdferr         ! Error code
 !*****
     INTEGER :: namelen                     ! Name length
-
     TYPE(C_PTR) :: f_ptr
 
     f_ptr = C_LOC(ref)
@@ -309,9 +293,7 @@ CONTAINS
 !  space_id 	 - dataspace identifier that describes selected region
 ! OUTPUTS
 !  ref 	         - reference to the dataset region
-!  hdferr:	 - error code
-!                   Success:  0
-!                   Failure: -1
+!  hdferr        - returns 0 if successful and -1 if fails
 ! AUTHOR
 !  Elena Pourmal
 !  August 12, 1999
@@ -376,9 +358,7 @@ CONTAINS
 !                H5T_STD_REF_DSETREG
 ! Outputs:
 !  ref	      - reference created by the function call.
-!  hdferr     - error code
-!		   Success:  0
-!		   Failure: -1
+!  hdferr     - returns 0 if successful and -1 if fails.
 ! OPTIONAL
 !  space_id   - dataspace identifier that describes selected region
 !
@@ -425,9 +405,7 @@ CONTAINS
 !  ref 	    - reference to open
 ! Outputs:
 !  obj_id   - object_identifier
-!  hdferr:  - error code
-!              Success:  0
-!              Failure: -1
+!  hdferr   - returns 0 if successful and -1 if fails
 ! AUTHOR
 !  Elena Pourmal
 !  August 12, 1999
@@ -449,7 +427,6 @@ CONTAINS
     INTEGER(HID_T), INTENT(OUT) :: ref_obj_id     ! Object identifier
     INTEGER, INTENT(OUT) :: hdferr                ! Error code
 !*****
-    INTEGER(HADDR_T) :: ref_f          ! Local buffer to pass reference
     TYPE(C_PTR) :: f_ptr
 
     f_ptr = C_LOC(ref)
@@ -465,14 +442,12 @@ CONTAINS
 !  Opens the dataset region
 !
 ! Inputs:
-!  dset_id 	 - identifier of the dataset containing
-!                  reference to teh regions
-!  ref 	         - reference to open
+!  dset_id  - identifier of the dataset containing
+!             reference to teh regions
+!  ref 	    - reference to open
 ! Outputs:
-!  obj_id 	 - dataspace identifier
-!  hdferr:	 - error code
-!                   Success:  0
-!                   Failure: -1
+!  obj_id   - dataspace identifier
+!  hdferr   - returns 0 if successful and -1 if fails
 !
 ! AUTHOR
 !  Elena Pourmal
@@ -517,9 +492,8 @@ CONTAINS
 !  ref        - Reference to open.
 ! Outputs:
 !  ref_obj_id - identifier of referenced object
-!  hdferr     - error code
-!		 Success:  0
-!		 Failure: -1
+!  hdferr     - returns 0 if successful and -1 if fails
+!
 ! AUTHOR
 !  M. Scot Breitenfeld
 !  June 20, 2008
@@ -553,37 +527,31 @@ CONTAINS
 !  Retrieves a name of a referenced object.
 !
 ! Inputs:
-!  loc_id    - Identifier for the dataset containing the reference or for the group that dataset is in.
+!  loc_id    - Identifier for the file containing the reference or for any object in that file.
 !  ref 	     - An object or dataset region reference.
 !
 ! Outputs:
 !  name      - A name associated with the referenced object or dataset region.
-!
-!  hdferr:   - error code
-!               Success:  0
-!               Failure: -1
+!  hdferr    - Returns 0 if successful and -1 if fails.
 !
 ! Optional parameters:
-!  size     - The size of the name buffer.
+!  size     - The size of the name buffer, returning 0 (zero) if no name is associated 
+!             with the identifier.
 !
 ! AUTHOR
 !  M. Scot Breitenfeld
 !  March 28, 2008
 !
-! Signature:S
+! Signature:
   SUBROUTINE h5rget_name_object_f(loc_id,  ref, name, hdferr, size)
     USE, INTRINSIC :: ISO_C_BINDING
     IMPLICIT NONE
-    INTEGER(HID_T), INTENT(IN) :: loc_id   ! Identifier for the dataset containing the reference
-                                           ! or for the group that dataset is in.
-    TYPE(hobj_ref_t_f), INTENT(IN), TARGET :: ref  ! Object reference
-    INTEGER(SIZE_T), OPTIONAL, INTENT(OUT) :: size ! The size of the name buffer,
-                                                   ! returning 0 (zero) if no name is associated
-                                                   ! with the identifier
-    CHARACTER(LEN=*), INTENT(OUT) :: name  ! A name associated with the referenced object or dataset region.
-    INTEGER, INTENT(OUT) :: hdferr         ! Error code
+    INTEGER(HID_T), INTENT(IN) :: loc_id
+    TYPE(hobj_ref_t_f), INTENT(IN), TARGET :: ref
+    INTEGER(SIZE_T), OPTIONAL, INTENT(OUT) :: size
+    CHARACTER(LEN=*), INTENT(INOUT) :: name
+    INTEGER, INTENT(OUT) :: hdferr
 !*****
-    INTEGER(HADDR_T) :: ref_f              ! Local buffer to pass reference
 
     INTEGER(SIZE_T) :: size_default
     INTEGER(SIZE_T) :: name_len
@@ -595,7 +563,6 @@ CONTAINS
 
     hdferr = h5rget_name_ptr_c(loc_id, 0, f_ptr, name, name_len, size_default)
 
-
     IF(PRESENT(size)) size = size_default
 
   END SUBROUTINE h5rget_name_object_f
@@ -608,18 +575,15 @@ CONTAINS
 !  Retrieves a name of a dataset region.
 !
 ! Inputs:
-!  loc_id  - Identifier for the dataset containing the reference or
-!            for the group that dataset is in.
+!  loc_id  - Identifier for the file containing the reference or for any object in that file.
 !  ref 	   - An object or dataset region reference.
 !
 ! Outputs:
 !  name    - A name associated with the referenced object or dataset region.
-!  hdferr  - error code
-!              Success:  0
-!              Failure: -1
+!  hdferr  - Returns 0 if successful and -1 if fails.
 !
 ! Optional parameters:
-!  size    - The size of the name buffer.
+!  size    - The size of the name buffer, returning 0 (zero) if no name is associated with the identifier
 !
 ! AUTHOR
 !  M. Scot Breitenfeld
@@ -629,15 +593,12 @@ CONTAINS
   SUBROUTINE h5rget_name_region_f(loc_id, ref, name, hdferr, size)
     USE, INTRINSIC :: ISO_C_BINDING
     IMPLICIT NONE
-    INTEGER(HID_T), INTENT(IN) :: loc_id   ! Identifier for the dataset containing the reference
-                                           ! or for the group that dataset is in.
-    TYPE(hdset_reg_ref_t_f), INTENT(IN), TARGET :: ref ! Object reference
-    INTEGER(SIZE_T), OPTIONAL, INTENT(OUT) :: size     ! The size of the name buffer,
-                                                       ! returning 0 (zero) if no name is associated with the identifier
-    CHARACTER(LEN=*), INTENT(OUT) :: name  ! A name associated with the referenced object or dataset region.
-    INTEGER, INTENT(OUT) :: hdferr         ! Error code
+    INTEGER(HID_T), INTENT(IN) :: loc_id
+    TYPE(hdset_reg_ref_t_f), INTENT(IN), TARGET :: ref
+    INTEGER(SIZE_T), OPTIONAL, INTENT(OUT) :: size
+    CHARACTER(LEN=*), INTENT(INOUT) :: name
+    INTEGER, INTENT(OUT) :: hdferr
 !*****
-    INTEGER :: ref_f(REF_REG_BUF_LEN)      ! Local buffer to pass reference
     INTEGER(SIZE_T) :: size_default
     INTEGER(SIZE_T) :: name_len
     TYPE(C_PTR) :: f_ptr
@@ -661,20 +622,17 @@ CONTAINS
   !  Retrieves a name of a referenced object.
   !
   ! Inputs:
-  !  loc_id   - Identifier for the dataset containing the reference or
-  !             for the group that dataset is in.
+  !  loc_id   - Identifier for the file containing the reference or for any object in that file.
   !  ref_type - Type of reference.
   !  ref      - An object or dataset region reference.
   !
   ! Outputs:
   !  name     - A name associated with the referenced object or dataset ptr.
-  !
-  !  hdferr   - error code
-  !		  Success:  0
-  !		  Failure: -1
+  !  hdferr   - Returns 0 if successful and -1 if fails.
   !
   ! Optional parameters:
-  !   size   - The size of the name buffer.
+  !   size    - The size of the name buffer, returning 0 (zero) if no name is associated
+  !             with the identifier
   !
   ! AUTHOR
   !  M. Scot Breitenfeld
@@ -684,15 +642,12 @@ CONTAINS
   SUBROUTINE h5rget_name_ptr_f(loc_id, ref_type, ref, name, hdferr, size)
     USE, INTRINSIC :: ISO_C_BINDING
     IMPLICIT NONE
-    INTEGER(HID_T), INTENT(IN) :: loc_id   ! Identifier for the dataset containing the reference
-                                           !  or for the group that dataset is in.
-    INTEGER, INTENT(IN) :: ref_type ! Type of reference.
-    TYPE(C_PTR), INTENT(IN) :: ref  ! An object or dataset region reference.
-    CHARACTER(LEN=*), INTENT(OUT) :: name  ! A name associated with the referenced object or dataset ptr.
-    INTEGER, INTENT(OUT) :: hdferr         ! Error code
-    INTEGER(SIZE_T), OPTIONAL, INTENT(OUT) :: size   ! The size of the name buffer,
-                                                     ! returning 0 (zero) if no name is associated
-                                                     ! with the identifier
+    INTEGER(HID_T), INTENT(IN) :: loc_id
+    INTEGER, INTENT(IN) :: ref_type
+    TYPE(C_PTR), INTENT(IN) :: ref
+    CHARACTER(LEN=*), INTENT(INOUT) :: name
+    INTEGER, INTENT(OUT) :: hdferr
+    INTEGER(SIZE_T), OPTIONAL, INTENT(OUT) :: size
 !*****
     INTEGER(SIZE_T) :: size_default
     INTEGER(SIZE_T) :: name_len
@@ -721,15 +676,12 @@ CONTAINS
   !
   ! Outputs:
   !  obj_type - Type of referenced object. 
-  !               H5G_UNKNOWN_F (-1)
-  !               H5G_LINK_F      0
-  !               H5G_GROUP_F     1
-  !               H5G_DATASET_F   2
-  !               H5G_TYPE_F      3
+  !               H5G_UNKNOWN_F
+  !               H5G_GROUP_F
+  !               H5G_DATASET_F
+  !               H5G_TYPE_F
   !              
-  !  hdferr   - error code
-  !		  Success:  0
-  !		  Failure: -1
+  !  hdferr   - Returns 0 if successful and -1 if fails.
   !
   ! AUTHOR
   !  M. Scot Breitenfeld
@@ -747,12 +699,10 @@ CONTAINS
     !*****
 
     INTERFACE
-       INTEGER FUNCTION h5rget_obj_type_c(loc_id, ref_type, ref, obj_type)
-         USE, INTRINSIC :: ISO_C_BINDING
+       INTEGER FUNCTION h5rget_obj_type_c(loc_id, ref_type, ref, obj_type) &
+            BIND(C, NAME='h5rget_obj_type_c')
+         USE, INTRINSIC :: ISO_C_BINDING, ONLY : c_ptr
          USE H5GLOBAL
-         !DEC$IF DEFINED(HDF5F90_WINDOWS)
-         !DEC$ATTRIBUTES C,reference,decorate,alias:'H5RGET_OBJ_TYPE_C':: h5rget_obj_type_c
-         !DEC$ENDIF
          INTEGER(HID_T), INTENT(IN) :: loc_id
          INTEGER, INTENT(IN) :: ref_type
          TYPE(C_PTR), VALUE :: ref
