@@ -6,7 +6,7 @@
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -15,79 +15,68 @@
 /* Module Setup */
 /****************/
 
-#define H5D_PACKAGE		/*suppress error about including H5Dpkg	  */
-#define H5O_PACKAGE		/*suppress error about including H5Opkg	  */
-
+#define H5D_PACKAGE /*suppress error about including H5Dpkg	  */
+#define H5O_PACKAGE /*suppress error about including H5Opkg	  */
 
 /***********/
 /* Headers */
 /***********/
-#include "H5private.h"		/* Generic Functions			*/
-#include "H5Dpkg.h"		/* Datasets				*/
-#include "H5Eprivate.h"		/* Error handling		  	*/
-#include "H5FLprivate.h"	/* Free lists                           */
-#include "H5Iprivate.h"		/* IDs			  		*/
-#include "H5Opkg.h"             /* Object headers			*/
-
+#include "H5private.h"   /* Generic Functions			*/
+#include "H5Dpkg.h"      /* Datasets				*/
+#include "H5Eprivate.h"  /* Error handling		  	*/
+#include "H5FLprivate.h" /* Free lists                           */
+#include "H5Iprivate.h"  /* IDs			  		*/
+#include "H5Opkg.h"      /* Object headers			*/
 
 /****************/
 /* Local Macros */
 /****************/
 
-
 /******************/
 /* Local Typedefs */
 /******************/
 
-
 /********************/
 /* Local Prototypes */
 /********************/
-static void *H5O__dset_get_copy_file_udata(void);
-static void H5O__dset_free_copy_file_udata(void *);
-static htri_t H5O__dset_isa(H5O_t *loc);
-static hid_t H5O__dset_open(const H5G_loc_t *obj_loc, hid_t lapl_id,
-    hid_t dxpl_id, hbool_t app_ref);
-static void *H5O__dset_create(H5F_t *f, void *_crt_info, H5G_loc_t *obj_loc,
-    hid_t dxpl_id);
+static void      *H5O__dset_get_copy_file_udata(void);
+static void       H5O__dset_free_copy_file_udata(void *);
+static htri_t     H5O__dset_isa(H5O_t *loc);
+static hid_t      H5O__dset_open(const H5G_loc_t *obj_loc, hid_t lapl_id, hid_t dxpl_id, hbool_t app_ref);
+static void      *H5O__dset_create(H5F_t *f, void *_crt_info, H5G_loc_t *obj_loc, hid_t dxpl_id);
 static H5O_loc_t *H5O__dset_get_oloc(hid_t obj_id);
-static herr_t H5O__dset_bh_info(H5F_t *f, hid_t dxpl_id, H5O_t *oh,
-    H5_ih_info_t *bh_info);
-static herr_t H5O__dset_flush(H5G_loc_t *obj_loc, hid_t dxpl_id);
-
+static herr_t     H5O__dset_bh_info(H5F_t *f, hid_t dxpl_id, H5O_t *oh, H5_ih_info_t *bh_info);
+static herr_t     H5O__dset_flush(H5G_loc_t *obj_loc, hid_t dxpl_id);
 
 /*********************/
 /* Package Variables */
 /*********************/
 
-
 /*****************************/
 /* Library Private Variables */
 /*****************************/
 
-
 /*******************/
 /* Local Variables */
 /*******************/
 
 /* This message derives from H5O object class */
 const H5O_obj_class_t H5O_OBJ_DATASET[1] = {{
-    H5O_TYPE_DATASET,		/* object type			*/
-    "dataset",			/* object name, for debugging	*/
-    H5O__dset_get_copy_file_udata, /* get 'copy file' user data	*/
+    H5O_TYPE_DATASET,               /* object type			*/
+    "dataset",                      /* object name, for debugging	*/
+    H5O__dset_get_copy_file_udata,  /* get 'copy file' user data	*/
     H5O__dset_free_copy_file_udata, /* free 'copy file' user data	*/
-    H5O__dset_isa, 		/* "isa" message		*/
-    H5O__dset_open, 		/* open an object of this class */
-    H5O__dset_create, 		/* create an object of this class */
-    H5O__dset_get_oloc, 	/* get an object header location for an object */
-    H5O__dset_bh_info, 		/* get the index & heap info for an object */
-    H5O__dset_flush 		/* flush an opened object of this class */
+    H5O__dset_isa,                  /* "isa" message		*/
+    H5O__dset_open,                 /* open an object of this class */
+    H5O__dset_create,               /* create an object of this class */
+    H5O__dset_get_oloc,             /* get an object header location for an object */
+    H5O__dset_bh_info,              /* get the index & heap info for an object */
+    H5O__dset_flush                 /* flush an opened object of this class */
 }};
 
 /* Declare a free list to manage the H5D_copy_file_ud_t struct */
 H5FL_DEFINE(H5D_copy_file_ud_t);
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5O__dset_get_copy_file_udata
  *
@@ -106,19 +95,18 @@ H5FL_DEFINE(H5D_copy_file_ud_t);
 static void *
 H5O__dset_get_copy_file_udata(void)
 {
-    void *ret_value;       /* Return value */
+    void *ret_value = NULL; /* Return value */
 
     FUNC_ENTER_STATIC
 
     /* Allocate space for the 'copy file' user data for copying datasets */
-    if(NULL == (ret_value = H5FL_CALLOC(H5D_copy_file_ud_t)))
+    if (NULL == (ret_value = H5FL_CALLOC(H5D_copy_file_ud_t)))
         HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, NULL, "memory allocation failed")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O__dset_get_copy_file_udata() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5O__dset_free_copy_file_udata
  *
@@ -143,15 +131,15 @@ H5O__dset_free_copy_file_udata(void *_udata)
     HDassert(udata);
 
     /* Release copy of dataset's dataspace extent, if it was set */
-    if(udata->src_space_extent)
+    if (udata->src_space_extent)
         H5O_msg_free(H5O_SDSPACE_ID, udata->src_space_extent);
 
     /* Release copy of dataset's datatype, if it was set */
-    if(udata->src_dtype)
+    if (udata->src_dtype)
         H5T_close(udata->src_dtype);
 
     /* Release copy of dataset's filter pipeline, if it was set */
-    if(udata->common.src_pline)
+    if (udata->common.src_pline)
         H5O_msg_free(H5O_PLINE_ID, udata->common.src_pline);
 
     /* Release space for 'copy file' user data */
@@ -160,7 +148,6 @@ H5O__dset_free_copy_file_udata(void *_udata)
     FUNC_LEAVE_NOAPI_VOID
 } /* end H5O__dset_free_copy_file_udata() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5O__dset_isa
  *
@@ -181,30 +168,29 @@ H5O__dset_free_copy_file_udata(void *_udata)
 static htri_t
 H5O__dset_isa(H5O_t *oh)
 {
-    htri_t	exists;                 /* Flag if header message of interest exists */
-    htri_t	ret_value = TRUE;       /* Return value */
+    htri_t exists;           /* Flag if header message of interest exists */
+    htri_t ret_value = TRUE; /* Return value */
 
     FUNC_ENTER_STATIC
 
     HDassert(oh);
 
     /* Datatype */
-    if((exists = H5O_msg_exists_oh(oh, H5O_DTYPE_ID)) < 0)
-	HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to read object header")
-    else if(!exists)
-	HGOTO_DONE(FALSE)
+    if ((exists = H5O_msg_exists_oh(oh, H5O_DTYPE_ID)) < 0)
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to read object header")
+    else if (!exists)
+        HGOTO_DONE(FALSE)
 
     /* Layout */
-    if((exists = H5O_msg_exists_oh(oh, H5O_SDSPACE_ID)) < 0)
-	HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to read object header")
-    else if(!exists)
-	HGOTO_DONE(FALSE)
+    if ((exists = H5O_msg_exists_oh(oh, H5O_SDSPACE_ID)) < 0)
+        HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to read object header")
+    else if (!exists)
+        HGOTO_DONE(FALSE)
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O__dset_isa() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5O__dset_open
  *
@@ -221,44 +207,42 @@ done:
 static hid_t
 H5O__dset_open(const H5G_loc_t *obj_loc, hid_t lapl_id, hid_t dxpl_id, hbool_t app_ref)
 {
-    H5D_t       *dset = NULL;           /* Dataset opened */
-    htri_t  isdapl;                 /* lapl_id is a dapl */
-    hid_t   dapl_id;                /* dapl to use to open this dataset */
-    hid_t	ret_value;              /* Return value */
+    H5D_t *dset = NULL; /* Dataset opened */
+    htri_t isdapl;      /* lapl_id is a dapl */
+    hid_t  dapl_id;     /* dapl to use to open this dataset */
+    hid_t  ret_value;   /* Return value */
 
     FUNC_ENTER_STATIC
 
     HDassert(obj_loc);
 
     /* If the lapl passed in is a dapl, use it.  Otherwise, use the default dapl */
-    if(lapl_id == H5P_DEFAULT)
+    if (lapl_id == H5P_DEFAULT)
         isdapl = FALSE;
-    else
-        if((isdapl = H5P_isa_class(lapl_id, H5P_DATASET_ACCESS)) < 0)
-            HGOTO_ERROR(H5E_PLIST, H5E_CANTCOMPARE, FAIL, "unable to compare property list classes")
+    else if ((isdapl = H5P_isa_class(lapl_id, H5P_DATASET_ACCESS)) < 0)
+        HGOTO_ERROR(H5E_PLIST, H5E_CANTCOMPARE, FAIL, "unable to compare property list classes")
 
-    if(isdapl)
+    if (isdapl)
         dapl_id = lapl_id;
     else
         dapl_id = H5P_DATASET_ACCESS_DEFAULT;
 
     /* Open the dataset */
-    if(NULL == (dset = H5D_open(obj_loc, dapl_id, dxpl_id)))
+    if (NULL == (dset = H5D_open(obj_loc, dapl_id, dxpl_id)))
         HGOTO_ERROR(H5E_DATASET, H5E_CANTOPENOBJ, FAIL, "unable to open dataset")
 
     /* Register an ID for the dataset */
-    if((ret_value = H5I_register(H5I_DATASET, dset, app_ref)) < 0)
+    if ((ret_value = H5I_register(H5I_DATASET, dset, app_ref)) < 0)
         HGOTO_ERROR(H5E_ATOM, H5E_CANTREGISTER, FAIL, "unable to register dataset")
 
 done:
-    if(ret_value < 0)
-        if(dset && H5D_close(dset) < 0)
+    if (ret_value < 0)
+        if (dset && H5D_close(dset) < 0)
             HDONE_ERROR(H5E_DATASET, H5E_CLOSEERROR, FAIL, "unable to release dataset")
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O__dset_open() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5O__dset_create
  *
@@ -275,9 +259,9 @@ done:
 static void *
 H5O__dset_create(H5F_t *f, void *_crt_info, H5G_loc_t *obj_loc, hid_t dxpl_id)
 {
-    H5D_obj_create_t *crt_info = (H5D_obj_create_t *)_crt_info; /* Dataset creation parameters */
-    H5D_t *dset = NULL;         /* New dataset created */
-    void *ret_value;            /* Return value */
+    H5D_obj_create_t *crt_info  = (H5D_obj_create_t *)_crt_info; /* Dataset creation parameters */
+    H5D_t            *dset      = NULL;                          /* New dataset created */
+    void             *ret_value = NULL;                          /* Return value */
 
     FUNC_ENTER_STATIC
 
@@ -287,27 +271,27 @@ H5O__dset_create(H5F_t *f, void *_crt_info, H5G_loc_t *obj_loc, hid_t dxpl_id)
     HDassert(obj_loc);
 
     /* Create the the dataset */
-    if(NULL == (dset = H5D__create(f, crt_info->type_id, crt_info->space, crt_info->dcpl_id, crt_info->dapl_id, dxpl_id)))
+    if (NULL == (dset = H5D__create(f, crt_info->type_id, crt_info->space, crt_info->dcpl_id,
+                                    crt_info->dapl_id, dxpl_id)))
         HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, NULL, "unable to create dataset")
 
     /* Set up the new dataset's location */
-    if(NULL == (obj_loc->oloc = H5D_oloc(dset)))
+    if (NULL == (obj_loc->oloc = H5D_oloc(dset)))
         HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, NULL, "unable to get object location of dataset")
-    if(NULL == (obj_loc->path = H5D_nameof(dset)))
+    if (NULL == (obj_loc->path = H5D_nameof(dset)))
         HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, NULL, "unable to get path of dataset")
 
     /* Set the return value */
     ret_value = dset;
 
 done:
-    if(ret_value == NULL)
-        if(dset && H5D_close(dset) < 0)
+    if (ret_value == NULL)
+        if (dset && H5D_close(dset) < 0)
             HDONE_ERROR(H5E_DATASET, H5E_CLOSEERROR, NULL, "unable to release dataset")
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O__dset_create() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5O__dset_get_oloc
  *
@@ -324,24 +308,23 @@ done:
 static H5O_loc_t *
 H5O__dset_get_oloc(hid_t obj_id)
 {
-    H5D_t       *dset;                  /* Dataset opened */
-    H5O_loc_t	*ret_value;             /* Return value */
+    H5D_t     *dset;             /* Dataset opened */
+    H5O_loc_t *ret_value = NULL; /* Return value */
 
     FUNC_ENTER_STATIC
 
     /* Get the dataset */
-    if(NULL == (dset = (H5D_t *)H5I_object(obj_id)))
+    if (NULL == (dset = (H5D_t *)H5I_object(obj_id)))
         HGOTO_ERROR(H5E_OHDR, H5E_BADATOM, NULL, "couldn't get object from ID")
 
     /* Get the dataset's object header location */
-    if(NULL == (ret_value = H5D_oloc(dset)))
+    if (NULL == (ret_value = H5D_oloc(dset)))
         HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, NULL, "unable to get object location from object")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O__dset_get_oloc() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5O__dset_bh_info
  *
@@ -354,23 +337,19 @@ done:
  * Programmer:  Vailin Choi
  *              July 11, 2007
  *
- * Modification:Raymond Lu
- *              5 February, 2010
- *              I added the call to H5O_msg_reset after H5D_chunk_bh_info 
- *              to free the PLINE. 
  *-------------------------------------------------------------------------
  */
 static herr_t
 H5O__dset_bh_info(H5F_t *f, hid_t dxpl_id, H5O_t *oh, H5_ih_info_t *bh_info)
 {
-    H5O_layout_t        layout;         	/* Data storage layout message */
-    H5O_pline_t         pline;                  /* I/O pipeline message */
-    H5O_efl_t           efl;			/* External File List message */
-    hbool_t             layout_read = FALSE;    /* Whether the layout message was read */
-    hbool_t             pline_read = FALSE;     /* Whether the I/O pipeline message was read */
-    hbool_t             efl_read = FALSE;       /* Whether the external file list message was read */
-    htri_t		exists;                 /* Flag if header message of interest exists */
-    herr_t      	ret_value = SUCCEED;    /* Return value */
+    H5O_layout_t layout;              /* Data storage layout message */
+    H5O_pline_t  pline;               /* I/O pipeline message */
+    H5O_efl_t    efl;                 /* External File List message */
+    hbool_t      layout_read = FALSE; /* Whether the layout message was read */
+    hbool_t      pline_read  = FALSE; /* Whether the I/O pipeline message was read */
+    hbool_t      efl_read    = FALSE; /* Whether the external file list message was read */
+    htri_t       exists;              /* Flag if header message of interest exists */
+    herr_t       ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_STATIC
 
@@ -380,58 +359,57 @@ H5O__dset_bh_info(H5F_t *f, hid_t dxpl_id, H5O_t *oh, H5_ih_info_t *bh_info)
     HDassert(bh_info);
 
     /* Get the layout message from the object header */
-    if(NULL == H5O_msg_read_oh(f, dxpl_id, oh, H5O_LAYOUT_ID, &layout))
-	HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "can't find layout message")
+    if (NULL == H5O_msg_read_oh(f, dxpl_id, oh, H5O_LAYOUT_ID, &layout))
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "can't find layout message")
     layout_read = TRUE;
 
     /* Check for chunked dataset storage */
-    if(layout.type == H5D_CHUNKED && H5D__chunk_is_space_alloc(&layout.storage)) {
+    if (layout.type == H5D_CHUNKED && H5D__chunk_is_space_alloc(&layout.storage)) {
         /* Check for I/O pipeline message */
-        if((exists = H5O_msg_exists_oh(oh, H5O_PLINE_ID)) < 0)
+        if ((exists = H5O_msg_exists_oh(oh, H5O_PLINE_ID)) < 0)
             HGOTO_ERROR(H5E_DATASET, H5E_CANTINIT, FAIL, "unable to read object header")
-        else if(exists) {
-            if(NULL == H5O_msg_read_oh(f, dxpl_id, oh, H5O_PLINE_ID, &pline))
+        else if (exists) {
+            if (NULL == H5O_msg_read_oh(f, dxpl_id, oh, H5O_PLINE_ID, &pline))
                 HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "can't find I/O pipeline message")
             pline_read = TRUE;
         } /* end else if */
         else
             HDmemset(&pline, 0, sizeof(pline));
 
-        if(H5D__chunk_bh_info(f, dxpl_id, &layout, &pline, &(bh_info->index_size)) < 0)
+        if (H5D__chunk_bh_info(f, dxpl_id, &layout, &pline, &(bh_info->index_size)) < 0)
             HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "can't determine chunked dataset btree info")
     } /* end if */
 
     /* Check for External File List message in the object header */
-    if((exists = H5O_msg_exists_oh(oh, H5O_EFL_ID)) < 0)
-	HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "unable to check for EFL message")
+    if ((exists = H5O_msg_exists_oh(oh, H5O_EFL_ID)) < 0)
+        HGOTO_ERROR(H5E_OHDR, H5E_NOTFOUND, FAIL, "unable to check for EFL message")
 
-    if(exists && H5D__efl_is_space_alloc(&layout.storage)) {
+    if (exists && H5D__efl_is_space_alloc(&layout.storage)) {
         /* Start with clean EFL info */
         HDmemset(&efl, 0, sizeof(efl));
 
-	/* Get External File List message from the object header */
-	if(NULL == H5O_msg_read_oh(f, dxpl_id, oh, H5O_EFL_ID, &efl))
-	    HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "can't find EFL message")
+        /* Get External File List message from the object header */
+        if (NULL == H5O_msg_read_oh(f, dxpl_id, oh, H5O_EFL_ID, &efl))
+            HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "can't find EFL message")
         efl_read = TRUE;
 
-	/* Get size of local heap for EFL message's file list */
-	if(H5D__efl_bh_info(f, dxpl_id, &efl, &(bh_info->heap_size)) < 0)
+        /* Get size of local heap for EFL message's file list */
+        if (H5D__efl_bh_info(f, dxpl_id, &efl, &(bh_info->heap_size)) < 0)
             HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "can't determine EFL heap info")
     } /* end if */
 
 done:
     /* Free messages, if they've been read in */
-    if(layout_read && H5O_msg_reset(H5O_LAYOUT_ID, &layout) < 0)
+    if (layout_read && H5O_msg_reset(H5O_LAYOUT_ID, &layout) < 0)
         HDONE_ERROR(H5E_DATASET, H5E_CANTRESET, FAIL, "unable to reset data storage layout message")
-    if(pline_read && H5O_msg_reset(H5O_PLINE_ID, &pline) < 0)
+    if (pline_read && H5O_msg_reset(H5O_PLINE_ID, &pline) < 0)
         HDONE_ERROR(H5E_DATASET, H5E_CANTRESET, FAIL, "unable to reset I/O pipeline message")
-    if(efl_read && H5O_msg_reset(H5O_EFL_ID, &efl) < 0)
+    if (efl_read && H5O_msg_reset(H5O_EFL_ID, &efl) < 0)
         HDONE_ERROR(H5E_DATASET, H5E_CANTRESET, FAIL, "unable to reset external file list message")
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O__dset_bh_info() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5O__dset_flush
  *
@@ -448,9 +426,9 @@ done:
 static herr_t
 H5O__dset_flush(H5G_loc_t *obj_loc, hid_t dxpl_id)
 {
-    H5D_t       *dset = NULL;          /* Dataset opened */
-    H5O_type_t 	obj_type;              /* Type of object at location */
-    herr_t      ret_value = SUCCEED;    /* Return value */
+    H5D_t     *dset = NULL;         /* Dataset opened */
+    H5O_type_t obj_type;            /* Type of object at location */
+    herr_t     ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_STATIC
 
@@ -458,22 +436,21 @@ H5O__dset_flush(H5G_loc_t *obj_loc, hid_t dxpl_id)
     HDassert(obj_loc->oloc);
 
     /* Check that the object found is the correct type */
-    if(H5O_obj_type(obj_loc->oloc, &obj_type, dxpl_id) < 0)
+    if (H5O_obj_type(obj_loc->oloc, &obj_type, dxpl_id) < 0)
         HGOTO_ERROR(H5E_DATASET, H5E_CANTGET, FAIL, "can't get object type")
 
-    if(obj_type != H5O_TYPE_DATASET)
+    if (obj_type != H5O_TYPE_DATASET)
         HGOTO_ERROR(H5E_DATASET, H5E_BADTYPE, FAIL, "not a dataset")
 
     /* Open the dataset */
-    if(NULL == (dset = H5D_open(obj_loc, H5P_DATASET_ACCESS_DEFAULT, dxpl_id)))
+    if (NULL == (dset = H5D_open(obj_loc, H5P_DATASET_ACCESS_DEFAULT, dxpl_id)))
         HGOTO_ERROR(H5E_DATASET, H5E_CANTOPENOBJ, FAIL, "unable to open dataset")
-    
-    if(H5D__flush_real(dset, dxpl_id) < 0)
-	HDONE_ERROR(H5E_DATASET, H5E_WRITEERROR, FAIL, "unable to flush cached dataset info")
+
+    if (H5D__flush_real(dset, dxpl_id) < 0)
+        HDONE_ERROR(H5E_DATASET, H5E_WRITEERROR, FAIL, "unable to flush cached dataset info")
 
 done:
-    if(dset && H5D_close(dset) < 0)
-	HDONE_ERROR(H5E_DATASET, H5E_CLOSEERROR, FAIL, "unable to release dataset")
+    if (dset && H5D_close(dset) < 0)
+        HDONE_ERROR(H5E_DATASET, H5E_CLOSEERROR, FAIL, "unable to release dataset")
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O__dset_flush() */
-
