@@ -6,7 +6,7 @@
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -15,7 +15,7 @@
  *
  * Created:		H5HFbtree2.c
  *			Aug  7 2006
- *			Quincey Koziol <koziol@hdfgroup.org>
+ *			Quincey Koziol
  *
  * Purpose:		v2 B-tree callbacks for "huge" object tracker
  *
@@ -26,107 +26,95 @@
 /* Module Setup */
 /****************/
 
-#define H5HF_PACKAGE		/*suppress error about including H5HFpkg  */
-
+#define H5HF_PACKAGE /*suppress error about including H5HFpkg  */
 
 /***********/
 /* Headers */
 /***********/
-#include "H5private.h"		/* Generic Functions			*/
-#include "H5Eprivate.h"		/* Error handling		  	*/
-#include "H5HFpkg.h"		/* Fractal heaps			*/
-#include "H5MFprivate.h"	/* File memory management		*/
-
+#include "H5private.h"   /* Generic Functions			*/
+#include "H5Eprivate.h"  /* Error handling		  	*/
+#include "H5HFpkg.h"     /* Fractal heaps			*/
+#include "H5MFprivate.h" /* File memory management		*/
 
 /****************/
 /* Local Macros */
 /****************/
 
-
 /******************/
 /* Local Typedefs */
 /******************/
 
 /* v2 B-tree client callback context */
 typedef struct H5HF_huge_bt2_ctx_t {
-    uint8_t     sizeof_size;    /* Size of file sizes */
-    uint8_t     sizeof_addr;    /* Size of file addresses */
+    uint8_t sizeof_size; /* Size of file sizes */
+    uint8_t sizeof_addr; /* Size of file addresses */
 } H5HF_huge_bt2_ctx_t;
 
-
 /********************/
 /* Package Typedefs */
 /********************/
 
-
 /********************/
 /* Local Prototypes */
 /********************/
 
-
 /* v2 B-tree driver callbacks */
 
-static void *H5HF_huge_bt2_crt_context(void *udata);
+static void  *H5HF_huge_bt2_crt_context(void *udata);
 static herr_t H5HF_huge_bt2_dst_context(void *ctx);
-static void *H5HF_huge_bt2_crt_dbg_context(H5F_t *f, hid_t dxpl_id, haddr_t addr);
+static void  *H5HF_huge_bt2_crt_dbg_context(H5F_t *f, hid_t dxpl_id, haddr_t addr);
 
 static herr_t H5HF_huge_bt2_indir_store(void *native, const void *udata);
 static herr_t H5HF_huge_bt2_indir_compare(const void *rec1, const void *rec2, int *result);
-static herr_t H5HF_huge_bt2_indir_encode(uint8_t *raw, const void *native,
-    void *ctx);
-static herr_t H5HF_huge_bt2_indir_decode(const uint8_t *raw, void *native,
-    void *ctx);
-static herr_t H5HF_huge_bt2_indir_debug(FILE *stream, const H5F_t *f, hid_t dxpl_id,
-    int indent, int fwidth, const void *record, const void *_udata);
+static herr_t H5HF_huge_bt2_indir_encode(uint8_t *raw, const void *native, void *ctx);
+static herr_t H5HF_huge_bt2_indir_decode(const uint8_t *raw, void *native, void *ctx);
+static herr_t H5HF_huge_bt2_indir_debug(FILE *stream, const H5F_t *f, hid_t dxpl_id, int indent, int fwidth,
+                                        const void *record, const void *_udata);
 
 static herr_t H5HF_huge_bt2_filt_indir_store(void *native, const void *udata);
 static herr_t H5HF_huge_bt2_filt_indir_compare(const void *rec1, const void *rec2, int *result);
-static herr_t H5HF_huge_bt2_filt_indir_encode(uint8_t *raw, const void *native,
-    void *ctx);
-static herr_t H5HF_huge_bt2_filt_indir_decode(const uint8_t *raw, void *native,
-    void *ctx);
-static herr_t H5HF_huge_bt2_filt_indir_debug(FILE *stream, const H5F_t *f, hid_t dxpl_id,
-    int indent, int fwidth, const void *record, const void *_udata);
+static herr_t H5HF_huge_bt2_filt_indir_encode(uint8_t *raw, const void *native, void *ctx);
+static herr_t H5HF_huge_bt2_filt_indir_decode(const uint8_t *raw, void *native, void *ctx);
+static herr_t H5HF_huge_bt2_filt_indir_debug(FILE *stream, const H5F_t *f, hid_t dxpl_id, int indent,
+                                             int fwidth, const void *record, const void *_udata);
 
 static herr_t H5HF_huge_bt2_dir_store(void *native, const void *udata);
 static herr_t H5HF_huge_bt2_dir_compare(const void *rec1, const void *rec2, int *result);
-static herr_t H5HF_huge_bt2_dir_encode(uint8_t *raw, const void *native,
-    void *ctx);
-static herr_t H5HF_huge_bt2_dir_decode(const uint8_t *raw, void *native,
-    void *ctx);
-static herr_t H5HF_huge_bt2_dir_debug(FILE *stream, const H5F_t *f, hid_t dxpl_id,
-    int indent, int fwidth, const void *record, const void *_udata);
+static herr_t H5HF_huge_bt2_dir_encode(uint8_t *raw, const void *native, void *ctx);
+static herr_t H5HF_huge_bt2_dir_decode(const uint8_t *raw, void *native, void *ctx);
+static herr_t H5HF_huge_bt2_dir_debug(FILE *stream, const H5F_t *f, hid_t dxpl_id, int indent, int fwidth,
+                                      const void *record, const void *_udata);
 
 static herr_t H5HF_huge_bt2_filt_dir_store(void *native, const void *udata);
 static herr_t H5HF_huge_bt2_filt_dir_compare(const void *rec1, const void *rec2, int *result);
-static herr_t H5HF_huge_bt2_filt_dir_encode(uint8_t *raw, const void *native,
-    void *ctx);
-static herr_t H5HF_huge_bt2_filt_dir_decode(const uint8_t *raw, void *native,
-    void *ctx);
-static herr_t H5HF_huge_bt2_filt_dir_debug(FILE *stream, const H5F_t *f, hid_t dxpl_id,
-    int indent, int fwidth, const void *record, const void *_udata);
+static herr_t H5HF_huge_bt2_filt_dir_encode(uint8_t *raw, const void *native, void *ctx);
+static herr_t H5HF_huge_bt2_filt_dir_decode(const uint8_t *raw, void *native, void *ctx);
+static herr_t H5HF_huge_bt2_filt_dir_debug(FILE *stream, const H5F_t *f, hid_t dxpl_id, int indent,
+                                           int fwidth, const void *record, const void *_udata);
 
 /*********************/
 /* Package Variables */
 /*********************/
 /* v2 B-tree class for indirectly accessed 'huge' objects */
-const H5B2_class_t H5HF_HUGE_BT2_INDIR[1]={{ /* B-tree class information */
-    H5B2_FHEAP_HUGE_INDIR_ID,               /* Type of B-tree */
-    "H5B2_FHEAP_HUGE_INDIR_ID",             /* Name of B-tree class */
-    sizeof(H5HF_huge_bt2_indir_rec_t),      /* Size of native record */
-    H5HF_huge_bt2_crt_context,              /* Create client callback context */
-    H5HF_huge_bt2_dst_context,              /* Destroy client callback context */
-    H5HF_huge_bt2_indir_store,              /* Record storage callback */
-    H5HF_huge_bt2_indir_compare,            /* Record comparison callback */
-    H5HF_huge_bt2_indir_encode,             /* Record encoding callback */
-    H5HF_huge_bt2_indir_decode,             /* Record decoding callback */
-    H5HF_huge_bt2_indir_debug,              /* Record debugging callback */
-    H5HF_huge_bt2_crt_dbg_context,          /* Create debugging context */
-    H5HF_huge_bt2_dst_context               /* Destroy debugging context */
+const H5B2_class_t H5HF_HUGE_BT2_INDIR[1] = {{
+    /* B-tree class information */
+    H5B2_FHEAP_HUGE_INDIR_ID,          /* Type of B-tree */
+    "H5B2_FHEAP_HUGE_INDIR_ID",        /* Name of B-tree class */
+    sizeof(H5HF_huge_bt2_indir_rec_t), /* Size of native record */
+    H5HF_huge_bt2_crt_context,         /* Create client callback context */
+    H5HF_huge_bt2_dst_context,         /* Destroy client callback context */
+    H5HF_huge_bt2_indir_store,         /* Record storage callback */
+    H5HF_huge_bt2_indir_compare,       /* Record comparison callback */
+    H5HF_huge_bt2_indir_encode,        /* Record encoding callback */
+    H5HF_huge_bt2_indir_decode,        /* Record decoding callback */
+    H5HF_huge_bt2_indir_debug,         /* Record debugging callback */
+    H5HF_huge_bt2_crt_dbg_context,     /* Create debugging context */
+    H5HF_huge_bt2_dst_context          /* Destroy debugging context */
 }};
 
 /* v2 B-tree class for indirectly accessed, filtered 'huge' objects */
-const H5B2_class_t H5HF_HUGE_BT2_FILT_INDIR[1]={{ /* B-tree class information */
+const H5B2_class_t H5HF_HUGE_BT2_FILT_INDIR[1] = {{
+    /* B-tree class information */
     H5B2_FHEAP_HUGE_FILT_INDIR_ID,          /* Type of B-tree */
     "H5B2_FHEAP_HUGE_FILT_INDIR_ID",        /* Name of B-tree class */
     sizeof(H5HF_huge_bt2_filt_indir_rec_t), /* Size of native record */
@@ -142,42 +130,43 @@ const H5B2_class_t H5HF_HUGE_BT2_FILT_INDIR[1]={{ /* B-tree class information */
 }};
 
 /* v2 B-tree class for directly accessed 'huge' objects */
-const H5B2_class_t H5HF_HUGE_BT2_DIR[1]={{  /* B-tree class information */
-    H5B2_FHEAP_HUGE_DIR_ID,                 /* Type of B-tree */
-    "H5B2_FHEAP_HUGE_DIR_ID",               /* Name of B-tree class */
-    sizeof(H5HF_huge_bt2_dir_rec_t),        /* Size of native record */
-    H5HF_huge_bt2_crt_context,              /* Create client callback context */
-    H5HF_huge_bt2_dst_context,              /* Destroy client callback context */
-    H5HF_huge_bt2_dir_store,                /* Record storage callback */
-    H5HF_huge_bt2_dir_compare,              /* Record comparison callback */
-    H5HF_huge_bt2_dir_encode,               /* Record encoding callback */
-    H5HF_huge_bt2_dir_decode,               /* Record decoding callback */
-    H5HF_huge_bt2_dir_debug,                /* Record debugging callback */
-    H5HF_huge_bt2_crt_dbg_context,          /* Create debugging context */
-    H5HF_huge_bt2_dst_context               /* Destroy debugging context */
+const H5B2_class_t H5HF_HUGE_BT2_DIR[1] = {{
+    /* B-tree class information */
+    H5B2_FHEAP_HUGE_DIR_ID,          /* Type of B-tree */
+    "H5B2_FHEAP_HUGE_DIR_ID",        /* Name of B-tree class */
+    sizeof(H5HF_huge_bt2_dir_rec_t), /* Size of native record */
+    H5HF_huge_bt2_crt_context,       /* Create client callback context */
+    H5HF_huge_bt2_dst_context,       /* Destroy client callback context */
+    H5HF_huge_bt2_dir_store,         /* Record storage callback */
+    H5HF_huge_bt2_dir_compare,       /* Record comparison callback */
+    H5HF_huge_bt2_dir_encode,        /* Record encoding callback */
+    H5HF_huge_bt2_dir_decode,        /* Record decoding callback */
+    H5HF_huge_bt2_dir_debug,         /* Record debugging callback */
+    H5HF_huge_bt2_crt_dbg_context,   /* Create debugging context */
+    H5HF_huge_bt2_dst_context        /* Destroy debugging context */
 }};
 
 /* v2 B-tree class for directly accessed, filtered 'huge' objects */
-const H5B2_class_t H5HF_HUGE_BT2_FILT_DIR[1]={{ /* B-tree class information */
-    H5B2_FHEAP_HUGE_FILT_DIR_ID,            /* Type of B-tree */
-    "H5B2_FHEAP_HUGE_FILT_DIR_ID",          /* Name of B-tree class */
-    sizeof(H5HF_huge_bt2_filt_dir_rec_t),   /* Size of native record */
-    H5HF_huge_bt2_crt_context,              /* Create client callback context */
-    H5HF_huge_bt2_dst_context,              /* Destroy client callback context */
-    H5HF_huge_bt2_filt_dir_store,           /* Record storage callback */
-    H5HF_huge_bt2_filt_dir_compare,         /* Record comparison callback */
-    H5HF_huge_bt2_filt_dir_encode,          /* Record encoding callback */
-    H5HF_huge_bt2_filt_dir_decode,          /* Record decoding callback */
-    H5HF_huge_bt2_filt_dir_debug,           /* Record debugging callback */
-    H5HF_huge_bt2_crt_dbg_context,          /* Create debugging context */
-    H5HF_huge_bt2_dst_context               /* Destroy debugging context */
+const H5B2_class_t H5HF_HUGE_BT2_FILT_DIR[1] = {{
+    /* B-tree class information */
+    H5B2_FHEAP_HUGE_FILT_DIR_ID,          /* Type of B-tree */
+    "H5B2_FHEAP_HUGE_FILT_DIR_ID",        /* Name of B-tree class */
+    sizeof(H5HF_huge_bt2_filt_dir_rec_t), /* Size of native record */
+    H5HF_huge_bt2_crt_context,            /* Create client callback context */
+    H5HF_huge_bt2_dst_context,            /* Destroy client callback context */
+    H5HF_huge_bt2_filt_dir_store,         /* Record storage callback */
+    H5HF_huge_bt2_filt_dir_compare,       /* Record comparison callback */
+    H5HF_huge_bt2_filt_dir_encode,        /* Record encoding callback */
+    H5HF_huge_bt2_filt_dir_decode,        /* Record decoding callback */
+    H5HF_huge_bt2_filt_dir_debug,         /* Record debugging callback */
+    H5HF_huge_bt2_crt_dbg_context,        /* Create debugging context */
+    H5HF_huge_bt2_dst_context             /* Destroy debugging context */
 }};
 
 /*****************************/
 /* Library Private Variables */
 /*****************************/
 
-
 /*******************/
 /* Local Variables */
 /*******************/
@@ -185,8 +174,6 @@ const H5B2_class_t H5HF_HUGE_BT2_FILT_DIR[1]={{ /* B-tree class information */
 /* Declare a free list to manage the H5HF_huge_bt2_ctx_t struct */
 H5FL_DEFINE_STATIC(H5HF_huge_bt2_ctx_t);
 
-
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_crt_context
  *
@@ -205,9 +192,9 @@ H5FL_DEFINE_STATIC(H5HF_huge_bt2_ctx_t);
 static void *
 H5HF_huge_bt2_crt_context(void *_f)
 {
-    H5F_t *f = (H5F_t *)_f;     /* User data for building callback context */
-    H5HF_huge_bt2_ctx_t *ctx;   /* Callback context structure */
-    void *ret_value;            /* Return value */
+    H5F_t               *f = (H5F_t *)_f;  /* User data for building callback context */
+    H5HF_huge_bt2_ctx_t *ctx;              /* Callback context structure */
+    void                *ret_value = NULL; /* Return value */
 
     FUNC_ENTER_NOAPI_NOINIT
 
@@ -215,7 +202,7 @@ H5HF_huge_bt2_crt_context(void *_f)
     HDassert(f);
 
     /* Allocate callback context */
-    if(NULL == (ctx = H5FL_MALLOC(H5HF_huge_bt2_ctx_t)))
+    if (NULL == (ctx = H5FL_MALLOC(H5HF_huge_bt2_ctx_t)))
         HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, NULL, "can't allocate callback context")
 
     /* Determine the size of addresses & lengths in the file */
@@ -229,7 +216,6 @@ done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5HF_huge_bt2_crt_context() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_dst_context
  *
@@ -248,7 +234,7 @@ done:
 static herr_t
 H5HF_huge_bt2_dst_context(void *_ctx)
 {
-    H5HF_huge_bt2_ctx_t *ctx = (H5HF_huge_bt2_ctx_t *)_ctx;       /* Callback context structure */
+    H5HF_huge_bt2_ctx_t *ctx = (H5HF_huge_bt2_ctx_t *)_ctx; /* Callback context structure */
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
@@ -261,7 +247,6 @@ H5HF_huge_bt2_dst_context(void *_ctx)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_dst_context() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_crt_dbg_context
  *
@@ -278,8 +263,8 @@ H5HF_huge_bt2_dst_context(void *_ctx)
 static void *
 H5HF_huge_bt2_crt_dbg_context(H5F_t *f, hid_t H5_ATTR_UNUSED dxpl_id, haddr_t H5_ATTR_UNUSED addr)
 {
-    H5HF_huge_bt2_ctx_t *ctx;   /* Callback context structure */
-    void *ret_value;            /* Return value */
+    H5HF_huge_bt2_ctx_t *ctx;       /* Callback context structure */
+    void                *ret_value; /* Return value */
 
     FUNC_ENTER_NOAPI_NOINIT
 
@@ -287,7 +272,7 @@ H5HF_huge_bt2_crt_dbg_context(H5F_t *f, hid_t H5_ATTR_UNUSED dxpl_id, haddr_t H5
     HDassert(f);
 
     /* Allocate callback context */
-    if(NULL == (ctx = H5FL_MALLOC(H5HF_huge_bt2_ctx_t)))
+    if (NULL == (ctx = H5FL_MALLOC(H5HF_huge_bt2_ctx_t)))
         HGOTO_ERROR(H5E_HEAP, H5E_CANTALLOC, NULL, "can't allocate callback context")
 
     /* Determine the size of addresses & lengths in the file */
@@ -301,7 +286,6 @@ done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5HF_huge_bt2_crt_dbg_context() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_indir_found
  *
@@ -321,18 +305,11 @@ H5HF_huge_bt2_indir_found(const void *nrecord, void *op_data)
 {
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-#ifdef QAK
-HDfprintf(stderr, "%s: nrecord = {%a, %Hu, %Hu}\n", "H5HF_huge_bt2_indir_found",
-        ((const H5HF_huge_bt2_indir_rec_t *)nrecord)->addr,
-        ((const H5HF_huge_bt2_indir_rec_t *)nrecord)->len,
-        ((const H5HF_huge_bt2_indir_rec_t *)nrecord)->id);
-#endif /* QAK */
     *(H5HF_huge_bt2_indir_rec_t *)op_data = *(const H5HF_huge_bt2_indir_rec_t *)nrecord;
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_indir_found() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_indir_remove
  *
@@ -350,13 +327,15 @@ HDfprintf(stderr, "%s: nrecord = {%a, %Hu, %Hu}\n", "H5HF_huge_bt2_indir_found",
 herr_t
 H5HF_huge_bt2_indir_remove(const void *nrecord, void *_udata)
 {
-    H5HF_huge_remove_ud_t *udata = (H5HF_huge_remove_ud_t *)_udata;   /* User callback data */
-    herr_t ret_value = SUCCEED;         /* Return value */
+    H5HF_huge_remove_ud_t *udata     = (H5HF_huge_remove_ud_t *)_udata; /* User callback data */
+    herr_t                 ret_value = SUCCEED;                         /* Return value */
 
     FUNC_ENTER_NOAPI_NOINIT
 
     /* Free the space in the file for the object being removed */
-    if(H5MF_xfree(udata->hdr->f, H5FD_MEM_FHEAP_HUGE_OBJ, udata->dxpl_id, ((const H5HF_huge_bt2_indir_rec_t *)nrecord)->addr, ((const H5HF_huge_bt2_indir_rec_t *)nrecord)->len) < 0)
+    if (H5MF_xfree(udata->hdr->f, H5FD_MEM_FHEAP_HUGE_OBJ, udata->dxpl_id,
+                   ((const H5HF_huge_bt2_indir_rec_t *)nrecord)->addr,
+                   ((const H5HF_huge_bt2_indir_rec_t *)nrecord)->len) < 0)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTFREE, FAIL, "unable to free space for huge object on disk")
 
     /* Set the length of the object removed */
@@ -366,7 +345,6 @@ done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5HF_huge_bt2_indir_remove() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_indir_store
  *
@@ -390,7 +368,6 @@ H5HF_huge_bt2_indir_store(void *nrecord, const void *udata)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_indir_store() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_indir_compare
  *
@@ -410,13 +387,12 @@ H5HF_huge_bt2_indir_compare(const void *_rec1, const void *_rec2, int *result)
 {
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    *result = (int)(((const H5HF_huge_bt2_indir_rec_t *)_rec1)->id - 
+    *result = (int)(((const H5HF_huge_bt2_indir_rec_t *)_rec1)->id -
                     ((const H5HF_huge_bt2_indir_rec_t *)_rec2)->id);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_indir_compare() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_indir_encode
  *
@@ -433,7 +409,7 @@ H5HF_huge_bt2_indir_compare(const void *_rec1, const void *_rec2, int *result)
 static herr_t
 H5HF_huge_bt2_indir_encode(uint8_t *raw, const void *_nrecord, void *_ctx)
 {
-    H5HF_huge_bt2_ctx_t *ctx = (H5HF_huge_bt2_ctx_t *)_ctx;       /* Callback context structure */
+    H5HF_huge_bt2_ctx_t             *ctx     = (H5HF_huge_bt2_ctx_t *)_ctx; /* Callback context structure */
     const H5HF_huge_bt2_indir_rec_t *nrecord = (const H5HF_huge_bt2_indir_rec_t *)_nrecord;
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
@@ -449,7 +425,6 @@ H5HF_huge_bt2_indir_encode(uint8_t *raw, const void *_nrecord, void *_ctx)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_indir_encode() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_indir_decode
  *
@@ -466,7 +441,7 @@ H5HF_huge_bt2_indir_encode(uint8_t *raw, const void *_nrecord, void *_ctx)
 static herr_t
 H5HF_huge_bt2_indir_decode(const uint8_t *raw, void *_nrecord, void *_ctx)
 {
-    H5HF_huge_bt2_ctx_t *ctx = (H5HF_huge_bt2_ctx_t *)_ctx;       /* Callback context structure */
+    H5HF_huge_bt2_ctx_t       *ctx     = (H5HF_huge_bt2_ctx_t *)_ctx; /* Callback context structure */
     H5HF_huge_bt2_indir_rec_t *nrecord = (H5HF_huge_bt2_indir_rec_t *)_nrecord;
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
@@ -482,7 +457,6 @@ H5HF_huge_bt2_indir_decode(const uint8_t *raw, void *_nrecord, void *_ctx)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_indir_decode() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_indir_debug
  *
@@ -498,20 +472,18 @@ H5HF_huge_bt2_indir_decode(const uint8_t *raw, void *_nrecord, void *_ctx)
  */
 static herr_t
 H5HF_huge_bt2_indir_debug(FILE *stream, const H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id,
-    int indent, int fwidth, const void *_nrecord,
-    const void H5_ATTR_UNUSED *_udata)
+                          int indent, int fwidth, const void *_nrecord, const void H5_ATTR_UNUSED *_udata)
 {
     const H5HF_huge_bt2_indir_rec_t *nrecord = (const H5HF_huge_bt2_indir_rec_t *)_nrecord;
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDfprintf(stream, "%*s%-*s {%a, %Hu, %Hu}\n", indent, "", fwidth, "Record:",
-        nrecord->addr, nrecord->len, nrecord->id);
+    HDfprintf(stream, "%*s%-*s {%" PRIuHADDR ", %" PRIuHSIZE ", %" PRIuHSIZE "}\n", indent, "", fwidth,
+              "Record:", nrecord->addr, nrecord->len, nrecord->id);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_indir_debug() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_filt_indir_found
  *
@@ -531,20 +503,11 @@ H5HF_huge_bt2_filt_indir_found(const void *nrecord, void *op_data)
 {
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-#ifdef QAK
-HDfprintf(stderr, "%s: nrecord = {%a, %Hu, %x, %Hu, %Hu}\n", "H5HF_huge_bt2_filt_indir_found",
-        ((const H5HF_huge_bt2_filt_indir_rec_t *)nrecord)->addr,
-        ((const H5HF_huge_bt2_filt_indir_rec_t *)nrecord)->len,
-        ((const H5HF_huge_bt2_filt_indir_rec_t *)nrecord)->filter_mask,
-        ((const H5HF_huge_bt2_filt_indir_rec_t *)nrecord)->obj_size,
-        ((const H5HF_huge_bt2_filt_indir_rec_t *)nrecord)->id);
-#endif /* QAK */
     *(H5HF_huge_bt2_filt_indir_rec_t *)op_data = *(const H5HF_huge_bt2_filt_indir_rec_t *)nrecord;
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_filt_indir_found() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_filt_indir_remove
  *
@@ -562,13 +525,15 @@ HDfprintf(stderr, "%s: nrecord = {%a, %Hu, %x, %Hu, %Hu}\n", "H5HF_huge_bt2_filt
 herr_t
 H5HF_huge_bt2_filt_indir_remove(const void *nrecord, void *_udata)
 {
-    H5HF_huge_remove_ud_t *udata = (H5HF_huge_remove_ud_t *)_udata;   /* User callback data */
-    herr_t ret_value = SUCCEED;         /* Return value */
+    H5HF_huge_remove_ud_t *udata     = (H5HF_huge_remove_ud_t *)_udata; /* User callback data */
+    herr_t                 ret_value = SUCCEED;                         /* Return value */
 
     FUNC_ENTER_NOAPI_NOINIT
 
     /* Free the space in the file for the object being removed */
-    if(H5MF_xfree(udata->hdr->f, H5FD_MEM_FHEAP_HUGE_OBJ, udata->dxpl_id, ((const H5HF_huge_bt2_filt_indir_rec_t *)nrecord)->addr, ((const H5HF_huge_bt2_filt_indir_rec_t *)nrecord)->len) < 0)
+    if (H5MF_xfree(udata->hdr->f, H5FD_MEM_FHEAP_HUGE_OBJ, udata->dxpl_id,
+                   ((const H5HF_huge_bt2_filt_indir_rec_t *)nrecord)->addr,
+                   ((const H5HF_huge_bt2_filt_indir_rec_t *)nrecord)->len) < 0)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTFREE, FAIL, "unable to free space for huge object on disk")
 
     /* Set the length of the object removed */
@@ -578,7 +543,6 @@ done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5HF_huge_bt2_filt_indir_remove() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_filt_indir_store
  *
@@ -602,7 +566,6 @@ H5HF_huge_bt2_filt_indir_store(void *nrecord, const void *udata)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_filt_indir_store() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_filt_indir_compare
  *
@@ -622,13 +585,12 @@ H5HF_huge_bt2_filt_indir_compare(const void *_rec1, const void *_rec2, int *resu
 {
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    *result = (int)(((const H5HF_huge_bt2_filt_indir_rec_t *)_rec1)->id - 
+    *result = (int)(((const H5HF_huge_bt2_filt_indir_rec_t *)_rec1)->id -
                     ((const H5HF_huge_bt2_filt_indir_rec_t *)_rec2)->id);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_filt_indir_compare() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_filt_indir_encode
  *
@@ -645,7 +607,7 @@ H5HF_huge_bt2_filt_indir_compare(const void *_rec1, const void *_rec2, int *resu
 static herr_t
 H5HF_huge_bt2_filt_indir_encode(uint8_t *raw, const void *_nrecord, void *_ctx)
 {
-    H5HF_huge_bt2_ctx_t *ctx = (H5HF_huge_bt2_ctx_t *)_ctx;       /* Callback context structure */
+    H5HF_huge_bt2_ctx_t                  *ctx = (H5HF_huge_bt2_ctx_t *)_ctx; /* Callback context structure */
     const H5HF_huge_bt2_filt_indir_rec_t *nrecord = (const H5HF_huge_bt2_filt_indir_rec_t *)_nrecord;
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
@@ -663,7 +625,6 @@ H5HF_huge_bt2_filt_indir_encode(uint8_t *raw, const void *_nrecord, void *_ctx)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_filt_indir_encode() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_filt_indir_decode
  *
@@ -680,7 +641,7 @@ H5HF_huge_bt2_filt_indir_encode(uint8_t *raw, const void *_nrecord, void *_ctx)
 static herr_t
 H5HF_huge_bt2_filt_indir_decode(const uint8_t *raw, void *_nrecord, void *_ctx)
 {
-    H5HF_huge_bt2_ctx_t *ctx = (H5HF_huge_bt2_ctx_t *)_ctx;       /* Callback context structure */
+    H5HF_huge_bt2_ctx_t            *ctx     = (H5HF_huge_bt2_ctx_t *)_ctx; /* Callback context structure */
     H5HF_huge_bt2_filt_indir_rec_t *nrecord = (H5HF_huge_bt2_filt_indir_rec_t *)_nrecord;
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
@@ -698,7 +659,6 @@ H5HF_huge_bt2_filt_indir_decode(const uint8_t *raw, void *_nrecord, void *_ctx)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_filt_indir_decode() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_filt_indir_debug
  *
@@ -714,20 +674,20 @@ H5HF_huge_bt2_filt_indir_decode(const uint8_t *raw, void *_nrecord, void *_ctx)
  */
 static herr_t
 H5HF_huge_bt2_filt_indir_debug(FILE *stream, const H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id,
-    int indent, int fwidth, const void *_nrecord,
-    const void H5_ATTR_UNUSED *_udata)
+                               int indent, int fwidth, const void *_nrecord,
+                               const void H5_ATTR_UNUSED *_udata)
 {
     const H5HF_huge_bt2_filt_indir_rec_t *nrecord = (const H5HF_huge_bt2_filt_indir_rec_t *)_nrecord;
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDfprintf(stream, "%*s%-*s {%a, %Hu, %x, %Hu, %Hu}\n", indent, "", fwidth, "Record:",
-        nrecord->addr, nrecord->len, nrecord->filter_mask, nrecord->obj_size, nrecord->id);
+    HDfprintf(stream, "%*s%-*s {%" PRIuHADDR ", %" PRIuHSIZE ", %x, %" PRIuHSIZE ", %" PRIuHSIZE "}\n",
+              indent, "", fwidth, "Record:", nrecord->addr, nrecord->len, nrecord->filter_mask,
+              nrecord->obj_size, nrecord->id);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_filt_indir_debug() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_dir_remove
  *
@@ -745,13 +705,15 @@ H5HF_huge_bt2_filt_indir_debug(FILE *stream, const H5F_t H5_ATTR_UNUSED *f, hid_
 herr_t
 H5HF_huge_bt2_dir_remove(const void *nrecord, void *_udata)
 {
-    H5HF_huge_remove_ud_t *udata = (H5HF_huge_remove_ud_t *)_udata;   /* User callback data */
-    herr_t ret_value = SUCCEED;         /* Return value */
+    H5HF_huge_remove_ud_t *udata     = (H5HF_huge_remove_ud_t *)_udata; /* User callback data */
+    herr_t                 ret_value = SUCCEED;                         /* Return value */
 
     FUNC_ENTER_NOAPI_NOINIT
 
     /* Free the space in the file for the object being removed */
-    if(H5MF_xfree(udata->hdr->f, H5FD_MEM_FHEAP_HUGE_OBJ, udata->dxpl_id, ((const H5HF_huge_bt2_indir_rec_t *)nrecord)->addr, ((const H5HF_huge_bt2_indir_rec_t *)nrecord)->len) < 0)
+    if (H5MF_xfree(udata->hdr->f, H5FD_MEM_FHEAP_HUGE_OBJ, udata->dxpl_id,
+                   ((const H5HF_huge_bt2_indir_rec_t *)nrecord)->addr,
+                   ((const H5HF_huge_bt2_indir_rec_t *)nrecord)->len) < 0)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTFREE, FAIL, "unable to free space for huge object on disk")
 
     /* Set the length of the object removed */
@@ -761,7 +723,6 @@ done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5HF_huge_bt2_dir_remove() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_dir_store
  *
@@ -785,7 +746,6 @@ H5HF_huge_bt2_dir_store(void *nrecord, const void *udata)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_dir_store() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_dir_compare
  *
@@ -808,17 +768,13 @@ H5HF_huge_bt2_dir_compare(const void *_rec1, const void *_rec2, int *result)
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-#ifdef QAK
-HDfprintf(stderr, "%s: rec1 = {%a, %Hu}\n", "H5HF_huge_bt2_dir_compare", rec1->addr, rec1->len);
-HDfprintf(stderr, "%s: rec2 = {%a, %Hu}\n", "H5HF_huge_bt2_dir_compare", rec2->addr, rec2->len);
-#endif /* QAK */
-    if(rec1->addr < rec2->addr)
+    if (rec1->addr < rec2->addr)
         *result = -1;
-    else if(rec1->addr > rec2->addr)
+    else if (rec1->addr > rec2->addr)
         *result = 1;
-    else if(rec1->len < rec2->len)
+    else if (rec1->len < rec2->len)
         *result = -1;
-    else if(rec1->len > rec2->len)
+    else if (rec1->len > rec2->len)
         *result = 1;
     else
         *result = 0;
@@ -826,7 +782,6 @@ HDfprintf(stderr, "%s: rec2 = {%a, %Hu}\n", "H5HF_huge_bt2_dir_compare", rec2->a
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_dir_compare() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_dir_encode
  *
@@ -843,7 +798,7 @@ HDfprintf(stderr, "%s: rec2 = {%a, %Hu}\n", "H5HF_huge_bt2_dir_compare", rec2->a
 static herr_t
 H5HF_huge_bt2_dir_encode(uint8_t *raw, const void *_nrecord, void *_ctx)
 {
-    H5HF_huge_bt2_ctx_t *ctx = (H5HF_huge_bt2_ctx_t *)_ctx;       /* Callback context structure */
+    H5HF_huge_bt2_ctx_t           *ctx     = (H5HF_huge_bt2_ctx_t *)_ctx; /* Callback context structure */
     const H5HF_huge_bt2_dir_rec_t *nrecord = (const H5HF_huge_bt2_dir_rec_t *)_nrecord;
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
@@ -858,7 +813,6 @@ H5HF_huge_bt2_dir_encode(uint8_t *raw, const void *_nrecord, void *_ctx)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_dir_encode() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_dir_decode
  *
@@ -875,7 +829,7 @@ H5HF_huge_bt2_dir_encode(uint8_t *raw, const void *_nrecord, void *_ctx)
 static herr_t
 H5HF_huge_bt2_dir_decode(const uint8_t *raw, void *_nrecord, void *_ctx)
 {
-    H5HF_huge_bt2_ctx_t *ctx = (H5HF_huge_bt2_ctx_t *)_ctx;       /* Callback context structure */
+    H5HF_huge_bt2_ctx_t     *ctx     = (H5HF_huge_bt2_ctx_t *)_ctx; /* Callback context structure */
     H5HF_huge_bt2_dir_rec_t *nrecord = (H5HF_huge_bt2_dir_rec_t *)_nrecord;
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
@@ -890,7 +844,6 @@ H5HF_huge_bt2_dir_decode(const uint8_t *raw, void *_nrecord, void *_ctx)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_dir_decode() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_dir_debug
  *
@@ -905,21 +858,19 @@ H5HF_huge_bt2_dir_decode(const uint8_t *raw, void *_nrecord, void *_ctx)
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5HF_huge_bt2_dir_debug(FILE *stream, const H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id,
-    int indent, int fwidth, const void *_nrecord,
-    const void H5_ATTR_UNUSED *_udata)
+H5HF_huge_bt2_dir_debug(FILE *stream, const H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id, int indent,
+                        int fwidth, const void *_nrecord, const void H5_ATTR_UNUSED *_udata)
 {
     const H5HF_huge_bt2_dir_rec_t *nrecord = (const H5HF_huge_bt2_dir_rec_t *)_nrecord;
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDfprintf(stream, "%*s%-*s {%a, %Hu}\n", indent, "", fwidth, "Record:",
-        nrecord->addr, nrecord->len);
+    HDfprintf(stream, "%*s%-*s {%" PRIuHADDR ", %" PRIuHSIZE "}\n", indent, "", fwidth,
+              "Record:", nrecord->addr, nrecord->len);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_dir_debug() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_filt_dir_found
  *
@@ -939,19 +890,11 @@ H5HF_huge_bt2_filt_dir_found(const void *nrecord, void *op_data)
 {
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-#ifdef QAK
-HDfprintf(stderr, "%s: nrecord = {%a, %Hu, %x, %Hu}\n", "H5HF_huge_bt2_filt_dir_found",
-        ((const H5HF_huge_bt2_filt_dir_rec_t *)nrecord)->addr,
-        ((const H5HF_huge_bt2_filt_dir_rec_t *)nrecord)->len,
-        ((const H5HF_huge_bt2_filt_dir_rec_t *)nrecord)->filter_mask,
-        ((const H5HF_huge_bt2_filt_dir_rec_t *)nrecord)->obj_size);
-#endif /* QAK */
     *(H5HF_huge_bt2_filt_dir_rec_t *)op_data = *(const H5HF_huge_bt2_filt_dir_rec_t *)nrecord;
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_filt_dir_found() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_filt_dir_remove
  *
@@ -969,13 +912,15 @@ HDfprintf(stderr, "%s: nrecord = {%a, %Hu, %x, %Hu}\n", "H5HF_huge_bt2_filt_dir_
 herr_t
 H5HF_huge_bt2_filt_dir_remove(const void *nrecord, void *_udata)
 {
-    H5HF_huge_remove_ud_t *udata = (H5HF_huge_remove_ud_t *)_udata;   /* User callback data */
-    herr_t ret_value = SUCCEED;         /* Return value */
+    H5HF_huge_remove_ud_t *udata     = (H5HF_huge_remove_ud_t *)_udata; /* User callback data */
+    herr_t                 ret_value = SUCCEED;                         /* Return value */
 
     FUNC_ENTER_NOAPI_NOINIT
 
     /* Free the space in the file for the object being removed */
-    if(H5MF_xfree(udata->hdr->f, H5FD_MEM_FHEAP_HUGE_OBJ, udata->dxpl_id, ((const H5HF_huge_bt2_filt_dir_rec_t *)nrecord)->addr, ((const H5HF_huge_bt2_filt_dir_rec_t *)nrecord)->len) < 0)
+    if (H5MF_xfree(udata->hdr->f, H5FD_MEM_FHEAP_HUGE_OBJ, udata->dxpl_id,
+                   ((const H5HF_huge_bt2_filt_dir_rec_t *)nrecord)->addr,
+                   ((const H5HF_huge_bt2_filt_dir_rec_t *)nrecord)->len) < 0)
         HGOTO_ERROR(H5E_HEAP, H5E_CANTFREE, FAIL, "unable to free space for huge object on disk")
 
     /* Set the length of the object removed */
@@ -985,7 +930,6 @@ done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* H5HF_huge_bt2_filt_dir_remove() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_filt_dir_store
  *
@@ -1009,7 +953,6 @@ H5HF_huge_bt2_filt_dir_store(void *nrecord, const void *udata)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_filt_dir_store() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_filt_dir_compare
  *
@@ -1032,17 +975,13 @@ H5HF_huge_bt2_filt_dir_compare(const void *_rec1, const void *_rec2, int *result
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-#ifdef QAK
-HDfprintf(stderr, "%s: rec1 = {%a, %Hu, %x, %Hu}\n", "H5HF_huge_bt2_filt_dir_compare", rec1->addr, rec1->len, rec1->filter_mask, rec1->obj_size);
-HDfprintf(stderr, "%s: rec2 = {%a, %Hu, %x, %Hu}\n", "H5HF_huge_bt2_filt_dir_compare", rec2->addr, rec2->len, rec2->filter_mask, rec2->obj_size);
-#endif /* QAK */
-    if(rec1->addr < rec2->addr)
+    if (rec1->addr < rec2->addr)
         *result = -1;
-    else if(rec1->addr > rec2->addr)
+    else if (rec1->addr > rec2->addr)
         *result = 1;
-    else if(rec1->len < rec2->len)
+    else if (rec1->len < rec2->len)
         *result = -1;
-    else if(rec1->len > rec2->len)
+    else if (rec1->len > rec2->len)
         *result = 1;
     else
         *result = 0;
@@ -1050,7 +989,6 @@ HDfprintf(stderr, "%s: rec2 = {%a, %Hu, %x, %Hu}\n", "H5HF_huge_bt2_filt_dir_com
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_filt_dir_compare() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_filt_dir_encode
  *
@@ -1067,7 +1005,7 @@ HDfprintf(stderr, "%s: rec2 = {%a, %Hu, %x, %Hu}\n", "H5HF_huge_bt2_filt_dir_com
 static herr_t
 H5HF_huge_bt2_filt_dir_encode(uint8_t *raw, const void *_nrecord, void *_ctx)
 {
-    H5HF_huge_bt2_ctx_t *ctx = (H5HF_huge_bt2_ctx_t *)_ctx;       /* Callback context structure */
+    H5HF_huge_bt2_ctx_t                *ctx = (H5HF_huge_bt2_ctx_t *)_ctx; /* Callback context structure */
     const H5HF_huge_bt2_filt_dir_rec_t *nrecord = (const H5HF_huge_bt2_filt_dir_rec_t *)_nrecord;
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
@@ -1084,7 +1022,6 @@ H5HF_huge_bt2_filt_dir_encode(uint8_t *raw, const void *_nrecord, void *_ctx)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_filt_dir_encode() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_filt_dir_decode
  *
@@ -1101,7 +1038,7 @@ H5HF_huge_bt2_filt_dir_encode(uint8_t *raw, const void *_nrecord, void *_ctx)
 static herr_t
 H5HF_huge_bt2_filt_dir_decode(const uint8_t *raw, void *_nrecord, void *_ctx)
 {
-    H5HF_huge_bt2_ctx_t *ctx = (H5HF_huge_bt2_ctx_t *)_ctx;       /* Callback context structure */
+    H5HF_huge_bt2_ctx_t          *ctx     = (H5HF_huge_bt2_ctx_t *)_ctx; /* Callback context structure */
     H5HF_huge_bt2_filt_dir_rec_t *nrecord = (H5HF_huge_bt2_filt_dir_rec_t *)_nrecord;
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
@@ -1118,7 +1055,6 @@ H5HF_huge_bt2_filt_dir_decode(const uint8_t *raw, void *_nrecord, void *_ctx)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_filt_dir_decode() */
 
-
 /*-------------------------------------------------------------------------
  * Function:	H5HF_huge_bt2_filt_dir_debug
  *
@@ -1134,15 +1070,14 @@ H5HF_huge_bt2_filt_dir_decode(const uint8_t *raw, void *_nrecord, void *_ctx)
  */
 static herr_t
 H5HF_huge_bt2_filt_dir_debug(FILE *stream, const H5F_t H5_ATTR_UNUSED *f, hid_t H5_ATTR_UNUSED dxpl_id,
-    int indent, int fwidth, const void *_nrecord, const void H5_ATTR_UNUSED *_udata)
+                             int indent, int fwidth, const void *_nrecord, const void H5_ATTR_UNUSED *_udata)
 {
     const H5HF_huge_bt2_filt_dir_rec_t *nrecord = (const H5HF_huge_bt2_filt_dir_rec_t *)_nrecord;
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDfprintf(stream, "%*s%-*s {%a, %Hu, %x, %Hu}\n", indent, "", fwidth, "Record:",
-        nrecord->addr, nrecord->len, nrecord->filter_mask, nrecord->obj_size);
+    HDfprintf(stream, "%*s%-*s {%" PRIuHADDR ", %" PRIuHSIZE ", %x, %" PRIuHSIZE "}\n", indent, "", fwidth,
+              "Record:", nrecord->addr, nrecord->len, nrecord->filter_mask, nrecord->obj_size);
 
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* H5HF_huge_bt2_filt_dir_debug() */
-
