@@ -5,19 +5,17 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the files COPYING and Copyright.html.  COPYING can be found at the root   *
- * of the source code distribution tree; Copyright.html can be found at the  *
- * root level of an installed copy of the electronic HDF5 document set and   *
- * is linked from the top-level documents page.  It can also be found at     *
- * http://hdfgroup.org/HDF5/doc/Copyright.html.  If you do not have          *
- * access to either file, you may request a copy from help@hdfgroup.org.     *
+ * the COPYING file, which can be found at the root of the source code       *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
+ * If you do not have access to either file, you may request a copy from     *
+ * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*-------------------------------------------------------------------------
  *
  * Created:		H5Pgcpl.c
  *			August 29 2006
- *			Quincey Koziol <koziol@ncsa.uiuc.edu>
+ *			Quincey Koziol
  *
  * Purpose:		Group creation property list class routines
  *
@@ -27,34 +25,30 @@
 /****************/
 /* Module Setup */
 /****************/
-#define H5P_PACKAGE		/*suppress error about including H5Ppkg	  */
+#define H5P_PACKAGE /*suppress error about including H5Ppkg	  */
 
 /***********/
 /* Headers */
 /***********/
-#include "H5private.h"		/* Generic Functions			*/
-#include "H5Eprivate.h"		/* Error handling		  	*/
-#include "H5Gprivate.h"         /* Groups                               */
-#include "H5Iprivate.h"		/* IDs			  		*/
-#include "H5Oprivate.h"		/* Object headers		  	*/
-#include "H5Ppkg.h"		/* Property lists		  	*/
-
+#include "H5private.h"  /* Generic Functions                        */
+#include "H5Eprivate.h" /* Error handling                           */
+#include "H5Gprivate.h" /* Groups                                   */
+#include "H5Iprivate.h" /* IDs                                      */
+#include "H5Oprivate.h" /* Object headers                           */
+#include "H5Ppkg.h"     /* Property lists                           */
 
 /****************/
 /* Local Macros */
 /****************/
 
-
 /******************/
 /* Local Typedefs */
 /******************/
 
-
 /********************/
 /* Package Typedefs */
 /********************/
 
-
 /********************/
 /* Local Prototypes */
 /********************/
@@ -62,42 +56,37 @@
 /* Property class callbacks */
 static herr_t H5P__gcrt_reg_prop(H5P_genclass_t *pclass);
 
-
 /*********************/
 /* Package Variables */
 /*********************/
 
 /* Group creation property list class library initialization object */
 const H5P_libclass_t H5P_CLS_GCRT[1] = {{
-    "group create",		/* Class name for debugging     */
-    H5P_TYPE_GROUP_CREATE,      /* Class type                   */
+    "group create",        /* Class name for debugging     */
+    H5P_TYPE_GROUP_CREATE, /* Class type                   */
 
-    &H5P_CLS_OBJECT_CREATE_g,	/* Parent class                 */
-    &H5P_CLS_GROUP_CREATE_g,	/* Pointer to class             */
-    &H5P_CLS_GROUP_CREATE_ID_g,	/* Pointer to class ID          */
-    &H5P_LST_GROUP_CREATE_ID_g,	/* Pointer to default property list ID */
-    H5P__gcrt_reg_prop,		/* Default property registration routine */
+    &H5P_CLS_OBJECT_CREATE_g,   /* Parent class                 */
+    &H5P_CLS_GROUP_CREATE_g,    /* Pointer to class             */
+    &H5P_CLS_GROUP_CREATE_ID_g, /* Pointer to class ID          */
+    &H5P_LST_GROUP_CREATE_ID_g, /* Pointer to default property list ID */
+    H5P__gcrt_reg_prop,         /* Default property registration routine */
 
-    NULL,		        /* Class creation callback      */
-    NULL,		        /* Class creation callback info */
-    NULL,			/* Class copy callback          */
-    NULL,		        /* Class copy callback info     */
-    NULL,			/* Class close callback         */
-    NULL 		        /* Class close callback info    */
+    NULL, /* Class creation callback      */
+    NULL, /* Class creation callback info */
+    NULL, /* Class copy callback          */
+    NULL, /* Class copy callback info     */
+    NULL, /* Class close callback         */
+    NULL  /* Class close callback info    */
 }};
 
-
 /*****************************/
 /* Library Private Variables */
 /*****************************/
 
-
 /*******************/
 /* Local Variables */
 /*******************/
 
-
-
 /*-------------------------------------------------------------------------
  * Function:    H5P__gcrt_reg_prop
  *
@@ -112,25 +101,26 @@ const H5P_libclass_t H5P_CLS_GCRT[1] = {{
 static herr_t
 H5P__gcrt_reg_prop(H5P_genclass_t *pclass)
 {
-    H5O_ginfo_t ginfo = H5G_CRT_GROUP_INFO_DEF;     /* Default group info settings */
-    H5O_linfo_t linfo = H5G_CRT_LINK_INFO_DEF;      /* Default link info settings */
-    herr_t ret_value = SUCCEED;         /* Return value */
+    H5O_ginfo_t ginfo     = H5G_CRT_GROUP_INFO_DEF; /* Default group info settings */
+    H5O_linfo_t linfo     = H5G_CRT_LINK_INFO_DEF;  /* Default link info settings */
+    herr_t      ret_value = SUCCEED;                /* Return value */
 
     FUNC_ENTER_STATIC
 
     /* Register group info property */
-    if(H5P_register_real(pclass, H5G_CRT_GROUP_INFO_NAME, H5G_CRT_GROUP_INFO_SIZE, &ginfo, NULL, NULL, NULL, NULL, NULL, NULL, NULL) < 0)
+    if (H5P_register_real(pclass, H5G_CRT_GROUP_INFO_NAME, H5G_CRT_GROUP_INFO_SIZE, &ginfo, NULL, NULL, NULL,
+                          NULL, NULL, NULL, NULL) < 0)
         HGOTO_ERROR(H5E_PLIST, H5E_CANTINSERT, FAIL, "can't insert property into class")
 
     /* Register link info property */
-    if(H5P_register_real(pclass, H5G_CRT_LINK_INFO_NAME, H5G_CRT_LINK_INFO_SIZE, &linfo, NULL, NULL, NULL, NULL, NULL, NULL, NULL) < 0)
+    if (H5P_register_real(pclass, H5G_CRT_LINK_INFO_NAME, H5G_CRT_LINK_INFO_SIZE, &linfo, NULL, NULL, NULL,
+                          NULL, NULL, NULL, NULL) < 0)
         HGOTO_ERROR(H5E_PLIST, H5E_CANTINSERT, FAIL, "can't insert property into class")
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5P__gcrt_reg_prop() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5Pset_local_heap_size_hint
  *
@@ -145,33 +135,32 @@ done:
 herr_t
 H5Pset_local_heap_size_hint(hid_t plist_id, size_t size_hint)
 {
-    H5P_genplist_t *plist;      /* Property list pointer */
-    H5O_ginfo_t ginfo;          /* Group information structure */
-    herr_t ret_value = SUCCEED;       /* Return value */
+    H5P_genplist_t *plist;               /* Property list pointer */
+    H5O_ginfo_t     ginfo;               /* Group information structure */
+    herr_t          ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_API(FAIL)
     H5TRACE2("e", "iz", plist_id, size_hint);
 
     /* Get the plist structure */
-    if(NULL == (plist = H5P_object_verify(plist_id, H5P_GROUP_CREATE)))
+    if (NULL == (plist = H5P_object_verify(plist_id, H5P_GROUP_CREATE)))
         HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
 
     /* Get value */
-    if(H5P_get(plist, H5G_CRT_GROUP_INFO_NAME, &ginfo) < 0)
+    if (H5P_get(plist, H5G_CRT_GROUP_INFO_NAME, &ginfo) < 0)
         HGOTO_ERROR(H5E_PLIST, H5E_CANTGET, FAIL, "can't get group info")
 
     /* Update field */
-    H5_ASSIGN_OVERFLOW(ginfo.lheap_size_hint, size_hint, size_t, uint32_t);
+    H5_CHECKED_ASSIGN(ginfo.lheap_size_hint, uint32_t, size_hint, size_t);
 
     /* Set value */
-    if(H5P_set(plist, H5G_CRT_GROUP_INFO_NAME, &ginfo) < 0)
+    if (H5P_set(plist, H5G_CRT_GROUP_INFO_NAME, &ginfo) < 0)
         HGOTO_ERROR(H5E_PLIST, H5E_CANTSET, FAIL, "can't set group info")
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Pset_local_heap_size_hint() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5Pget_local_heap_size_hint
  *
@@ -187,21 +176,21 @@ done:
 herr_t
 H5Pget_local_heap_size_hint(hid_t plist_id, size_t *size_hint /*out*/)
 {
-    herr_t ret_value = SUCCEED;   /* return value */
+    herr_t ret_value = SUCCEED; /* return value */
 
     FUNC_ENTER_API(FAIL)
     H5TRACE2("e", "ix", plist_id, size_hint);
 
-    if(size_hint) {
-        H5P_genplist_t *plist;      /* Property list pointer */
-        H5O_ginfo_t ginfo;          /* Group information structure */
+    if (size_hint) {
+        H5P_genplist_t *plist; /* Property list pointer */
+        H5O_ginfo_t     ginfo; /* Group information structure */
 
         /* Get the plist structure */
-        if(NULL == (plist = H5P_object_verify(plist_id, H5P_GROUP_CREATE)))
+        if (NULL == (plist = H5P_object_verify(plist_id, H5P_GROUP_CREATE)))
             HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
 
         /* Get value */
-        if(H5P_get(plist, H5G_CRT_GROUP_INFO_NAME, &ginfo) < 0)
+        if (H5P_get(plist, H5G_CRT_GROUP_INFO_NAME, &ginfo) < 0)
             HGOTO_ERROR(H5E_PLIST, H5E_CANTGET, FAIL, "can't get group info")
 
         /* Update field */
@@ -212,7 +201,6 @@ done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Pget_local_heap_size_hint() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5Pset_link_phase_change
  *
@@ -233,46 +221,45 @@ done:
 herr_t
 H5Pset_link_phase_change(hid_t plist_id, unsigned max_compact, unsigned min_dense)
 {
-    H5P_genplist_t *plist;              /* Property list pointer */
-    H5O_ginfo_t ginfo;                  /* Group information structure */
-    herr_t ret_value = SUCCEED;         /* Return value */
+    H5P_genplist_t *plist;               /* Property list pointer */
+    H5O_ginfo_t     ginfo;               /* Group information structure */
+    herr_t          ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_API(FAIL)
     H5TRACE3("e", "iIuIu", plist_id, max_compact, min_dense);
 
     /* Range check values */
-    if(max_compact < min_dense)
+    if (max_compact < min_dense)
         HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "max compact value must be >= min dense value")
-    if(max_compact > 65535)
+    if (max_compact > 65535)
         HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "max compact value must be < 65536")
-    if(min_dense > 65535)
+    if (min_dense > 65535)
         HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "min dense value must be < 65536")
 
     /* Get the plist structure */
-    if(NULL == (plist = H5P_object_verify(plist_id, H5P_GROUP_CREATE)))
+    if (NULL == (plist = H5P_object_verify(plist_id, H5P_GROUP_CREATE)))
         HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
 
     /* Get group info */
-    if(H5P_get(plist, H5G_CRT_GROUP_INFO_NAME, &ginfo) < 0)
+    if (H5P_get(plist, H5G_CRT_GROUP_INFO_NAME, &ginfo) < 0)
         HGOTO_ERROR(H5E_PLIST, H5E_CANTGET, FAIL, "can't get group info")
 
     /* Update fields */
-    if(max_compact != H5G_CRT_GINFO_MAX_COMPACT || min_dense != H5G_CRT_GINFO_MIN_DENSE)
+    if (max_compact != H5G_CRT_GINFO_MAX_COMPACT || min_dense != H5G_CRT_GINFO_MIN_DENSE)
         ginfo.store_link_phase_change = TRUE;
     else
         ginfo.store_link_phase_change = FALSE;
     ginfo.max_compact = (uint16_t)max_compact;
-    ginfo.min_dense = (uint16_t)min_dense;
+    ginfo.min_dense   = (uint16_t)min_dense;
 
     /* Set group info */
-    if(H5P_set(plist, H5G_CRT_GROUP_INFO_NAME, &ginfo) < 0)
+    if (H5P_set(plist, H5G_CRT_GROUP_INFO_NAME, &ginfo) < 0)
         HGOTO_ERROR(H5E_PLIST, H5E_CANTSET, FAIL, "can't set group info")
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Pset_link_phase_change() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5Pget_link_phase_change
  *
@@ -288,27 +275,27 @@ done:
 herr_t
 H5Pget_link_phase_change(hid_t plist_id, unsigned *max_compact /*out*/, unsigned *min_dense /*out*/)
 {
-    herr_t ret_value = SUCCEED;   /* return value */
+    herr_t ret_value = SUCCEED; /* return value */
 
     FUNC_ENTER_API(FAIL)
     H5TRACE3("e", "ixx", plist_id, max_compact, min_dense);
 
     /* Get values */
-    if(max_compact || min_dense) {
-        H5P_genplist_t *plist;      /* Property list pointer */
-        H5O_ginfo_t ginfo;          /* Group information structure */
+    if (max_compact || min_dense) {
+        H5P_genplist_t *plist; /* Property list pointer */
+        H5O_ginfo_t     ginfo; /* Group information structure */
 
         /* Get the plist structure */
-        if(NULL == (plist = H5P_object_verify(plist_id, H5P_GROUP_CREATE)))
+        if (NULL == (plist = H5P_object_verify(plist_id, H5P_GROUP_CREATE)))
             HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
 
         /* Get group info */
-        if(H5P_get(plist, H5G_CRT_GROUP_INFO_NAME, &ginfo) < 0)
+        if (H5P_get(plist, H5G_CRT_GROUP_INFO_NAME, &ginfo) < 0)
             HGOTO_ERROR(H5E_PLIST, H5E_CANTGET, FAIL, "can't get group info")
 
-        if(max_compact)
+        if (max_compact)
             *max_compact = ginfo.max_compact;
-        if(min_dense)
+        if (min_dense)
             *min_dense = ginfo.min_dense;
     } /* end if */
 
@@ -316,7 +303,6 @@ done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Pget_link_phase_change() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5Pset_est_link_info
  *
@@ -339,44 +325,43 @@ done:
 herr_t
 H5Pset_est_link_info(hid_t plist_id, unsigned est_num_entries, unsigned est_name_len)
 {
-    H5P_genplist_t *plist;              /* Property list pointer */
-    H5O_ginfo_t ginfo;                  /* Group information structure */
-    herr_t ret_value = SUCCEED;         /* Return value */
+    H5P_genplist_t *plist;               /* Property list pointer */
+    H5O_ginfo_t     ginfo;               /* Group information structure */
+    herr_t          ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_API(FAIL)
     H5TRACE3("e", "iIuIu", plist_id, est_num_entries, est_name_len);
 
     /* Range check values */
-    if(est_num_entries > 65535)
+    if (est_num_entries > 65535)
         HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "est. number of entries must be < 65536")
-    if(est_name_len > 65535)
+    if (est_name_len > 65535)
         HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, FAIL, "est. name length must be < 65536")
 
     /* Get the plist structure */
-    if(NULL == (plist = H5P_object_verify(plist_id, H5P_GROUP_CREATE)))
+    if (NULL == (plist = H5P_object_verify(plist_id, H5P_GROUP_CREATE)))
         HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
 
     /* Get group info */
-    if(H5P_get(plist, H5G_CRT_GROUP_INFO_NAME, &ginfo) < 0)
+    if (H5P_get(plist, H5G_CRT_GROUP_INFO_NAME, &ginfo) < 0)
         HGOTO_ERROR(H5E_PLIST, H5E_CANTGET, FAIL, "can't get group info")
 
     /* Update fields */
-    if(est_num_entries != H5G_CRT_GINFO_EST_NUM_ENTRIES || est_name_len != H5G_CRT_GINFO_EST_NAME_LEN)
+    if (est_num_entries != H5G_CRT_GINFO_EST_NUM_ENTRIES || est_name_len != H5G_CRT_GINFO_EST_NAME_LEN)
         ginfo.store_est_entry_info = TRUE;
     else
         ginfo.store_est_entry_info = FALSE;
     ginfo.est_num_entries = (uint16_t)est_num_entries;
-    ginfo.est_name_len = (uint16_t)est_name_len;
+    ginfo.est_name_len    = (uint16_t)est_name_len;
 
     /* Set group info */
-    if(H5P_set(plist, H5G_CRT_GROUP_INFO_NAME, &ginfo) < 0)
+    if (H5P_set(plist, H5G_CRT_GROUP_INFO_NAME, &ginfo) < 0)
         HGOTO_ERROR(H5E_PLIST, H5E_CANTSET, FAIL, "can't set group info")
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Pset_est_link_info() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5Pget_est_link_info
  *
@@ -392,27 +377,27 @@ done:
 herr_t
 H5Pget_est_link_info(hid_t plist_id, unsigned *est_num_entries /*out*/, unsigned *est_name_len /*out*/)
 {
-    herr_t ret_value = SUCCEED;   /* return value */
+    herr_t ret_value = SUCCEED; /* return value */
 
     FUNC_ENTER_API(FAIL)
     H5TRACE3("e", "ixx", plist_id, est_num_entries, est_name_len);
 
     /* Get values */
-    if(est_num_entries || est_name_len) {
-        H5P_genplist_t *plist;      /* Property list pointer */
-        H5O_ginfo_t ginfo;          /* Group information structure */
+    if (est_num_entries || est_name_len) {
+        H5P_genplist_t *plist; /* Property list pointer */
+        H5O_ginfo_t     ginfo; /* Group information structure */
 
         /* Get the plist structure */
-        if(NULL == (plist = H5P_object_verify(plist_id, H5P_GROUP_CREATE)))
+        if (NULL == (plist = H5P_object_verify(plist_id, H5P_GROUP_CREATE)))
             HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
 
         /* Get group info */
-        if(H5P_get(plist, H5G_CRT_GROUP_INFO_NAME, &ginfo) < 0)
+        if (H5P_get(plist, H5G_CRT_GROUP_INFO_NAME, &ginfo) < 0)
             HGOTO_ERROR(H5E_PLIST, H5E_CANTGET, FAIL, "can't get group info")
 
-        if(est_num_entries)
+        if (est_num_entries)
             *est_num_entries = ginfo.est_num_entries;
-        if(est_name_len)
+        if (est_name_len)
             *est_name_len = ginfo.est_name_len;
     } /* end if */
 
@@ -420,7 +405,6 @@ done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Pget_est_link_info() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5Pset_link_creation_order
  *
@@ -435,23 +419,23 @@ done:
 herr_t
 H5Pset_link_creation_order(hid_t plist_id, unsigned crt_order_flags)
 {
-    H5P_genplist_t *plist;              /* Property list pointer */
-    H5O_linfo_t linfo;                  /* Link information structure */
-    herr_t ret_value = SUCCEED;         /* Return value */
+    H5P_genplist_t *plist;               /* Property list pointer */
+    H5O_linfo_t     linfo;               /* Link information structure */
+    herr_t          ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_API(FAIL)
     H5TRACE2("e", "iIu", plist_id, crt_order_flags);
 
-        /* Check for bad combination of flags */
-    if(!(crt_order_flags & H5P_CRT_ORDER_TRACKED) && (crt_order_flags & H5P_CRT_ORDER_INDEXED))
+    /* Check for bad combination of flags */
+    if (!(crt_order_flags & H5P_CRT_ORDER_TRACKED) && (crt_order_flags & H5P_CRT_ORDER_INDEXED))
         HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "tracking creation order is required for index")
 
     /* Get the plist structure */
-    if(NULL == (plist = H5P_object_verify(plist_id, H5P_GROUP_CREATE)))
+    if (NULL == (plist = H5P_object_verify(plist_id, H5P_GROUP_CREATE)))
         HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
 
     /* Get link info */
-    if(H5P_get(plist, H5G_CRT_LINK_INFO_NAME, &linfo) < 0)
+    if (H5P_get(plist, H5G_CRT_LINK_INFO_NAME, &linfo) < 0)
         HGOTO_ERROR(H5E_PLIST, H5E_CANTGET, FAIL, "can't get link info")
 
     /* Update fields */
@@ -459,14 +443,13 @@ H5Pset_link_creation_order(hid_t plist_id, unsigned crt_order_flags)
     linfo.index_corder = (hbool_t)((crt_order_flags & H5P_CRT_ORDER_INDEXED) ? TRUE : FALSE);
 
     /* Set link info */
-    if(H5P_set(plist, H5G_CRT_LINK_INFO_NAME, &linfo) < 0)
+    if (H5P_set(plist, H5G_CRT_LINK_INFO_NAME, &linfo) < 0)
         HGOTO_ERROR(H5E_PLIST, H5E_CANTSET, FAIL, "can't set link info")
 
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Pset_link_creation_order() */
 
-
 /*-------------------------------------------------------------------------
  * Function:    H5Pget_link_creation_order
  *
@@ -482,25 +465,25 @@ done:
 herr_t
 H5Pget_link_creation_order(hid_t plist_id, unsigned *crt_order_flags /*out*/)
 {
-    herr_t ret_value = SUCCEED;   /* return value */
+    herr_t ret_value = SUCCEED; /* return value */
 
     FUNC_ENTER_API(FAIL)
     H5TRACE2("e", "ix", plist_id, crt_order_flags);
 
     /* Get values */
-    if(crt_order_flags) {
-        H5P_genplist_t *plist;      /* Property list pointer */
-        H5O_linfo_t linfo;          /* Link information structure */
+    if (crt_order_flags) {
+        H5P_genplist_t *plist; /* Property list pointer */
+        H5O_linfo_t     linfo; /* Link information structure */
 
         /* Reset the value to return */
         *crt_order_flags = 0;
 
         /* Get the plist structure */
-        if(NULL == (plist = H5P_object_verify(plist_id, H5P_GROUP_CREATE)))
+        if (NULL == (plist = H5P_object_verify(plist_id, H5P_GROUP_CREATE)))
             HGOTO_ERROR(H5E_ATOM, H5E_BADATOM, FAIL, "can't find object for ID")
 
         /* Get link info */
-        if(H5P_get(plist, H5G_CRT_LINK_INFO_NAME, &linfo) < 0)
+        if (H5P_get(plist, H5G_CRT_LINK_INFO_NAME, &linfo) < 0)
             HGOTO_ERROR(H5E_PLIST, H5E_CANTGET, FAIL, "can't get link info")
 
         *crt_order_flags |= linfo.track_corder ? H5P_CRT_ORDER_TRACKED : 0;
@@ -510,4 +493,3 @@ H5Pget_link_creation_order(hid_t plist_id, unsigned *crt_order_flags /*out*/)
 done:
     FUNC_LEAVE_API(ret_value)
 } /* end H5Pget_link_creation_order() */
-
