@@ -6,7 +6,7 @@
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -14,8 +14,8 @@
 /*
  * This file contains private information about the H5R module
  */
-#ifndef _H5Rprivate_H
-#define _H5Rprivate_H
+#ifndef H5Rprivate_H
+#define H5Rprivate_H
 
 #include "H5Rpublic.h"
 
@@ -25,5 +25,4 @@
 
 /* Private functions */
 
-#endif  /* _H5Rprivate_H */
-
+#endif /* H5Rprivate_H */
